Class: Aws::MediaTailor::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MediaTailor::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mediatailor/client.rb
Overview
An API client for MediaTailor. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MediaTailor::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#configure_logs_for_channel(params = {}) ⇒ Types::ConfigureLogsForChannelResponse
Configures Amazon CloudWatch log settings for a channel.
-
#configure_logs_for_playback_configuration(params = {}) ⇒ Types::ConfigureLogsForPlaybackConfigurationResponse
Defines where AWS Elemental MediaTailor sends logs for the playback configuration.
-
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a channel.
-
#create_live_source(params = {}) ⇒ Types::CreateLiveSourceResponse
The live source configuration.
-
#create_prefetch_schedule(params = {}) ⇒ Types::CreatePrefetchScheduleResponse
Creates a prefetch schedule for a playback configuration.
-
#create_program(params = {}) ⇒ Types::CreateProgramResponse
Creates a program within a channel.
-
#create_source_location(params = {}) ⇒ Types::CreateSourceLocationResponse
Creates a source location.
-
#create_vod_source(params = {}) ⇒ Types::CreateVodSourceResponse
The VOD source configuration parameters.
-
#delete_channel(params = {}) ⇒ Struct
Deletes a channel.
-
#delete_channel_policy(params = {}) ⇒ Struct
The channel policy to delete.
-
#delete_function(params = {}) ⇒ Struct
Deletes a function.
-
#delete_live_source(params = {}) ⇒ Struct
The live source to delete.
-
#delete_playback_configuration(params = {}) ⇒ Struct
Deletes a playback configuration.
-
#delete_prefetch_schedule(params = {}) ⇒ Struct
Deletes a prefetch schedule for a specific playback configuration.
-
#delete_program(params = {}) ⇒ Struct
Deletes a program within a channel.
-
#delete_source_location(params = {}) ⇒ Struct
Deletes a source location.
-
#delete_vod_source(params = {}) ⇒ Struct
The video on demand (VOD) source to delete.
-
#describe_channel(params = {}) ⇒ Types::DescribeChannelResponse
Describes a channel.
-
#describe_live_source(params = {}) ⇒ Types::DescribeLiveSourceResponse
The live source to describe.
-
#describe_program(params = {}) ⇒ Types::DescribeProgramResponse
Describes a program within a channel.
-
#describe_source_location(params = {}) ⇒ Types::DescribeSourceLocationResponse
Describes a source location.
-
#describe_vod_source(params = {}) ⇒ Types::DescribeVodSourceResponse
Provides details about a specific video on demand (VOD) source in a specific source location.
-
#get_channel_policy(params = {}) ⇒ Types::GetChannelPolicyResponse
Returns the channel’s IAM policy.
-
#get_channel_schedule(params = {}) ⇒ Types::GetChannelScheduleResponse
Retrieves information about your channel’s schedule.
-
#get_function(params = {}) ⇒ Types::GetFunctionResponse
Retrieves the configuration and metadata for a function.
-
#get_playback_configuration(params = {}) ⇒ Types::GetPlaybackConfigurationResponse
Retrieves a playback configuration.
-
#get_prefetch_schedule(params = {}) ⇒ Types::GetPrefetchScheduleResponse
Retrieves a prefetch schedule for a playback configuration.
-
#list_alerts(params = {}) ⇒ Types::ListAlertsResponse
Lists the alerts that are associated with a MediaTailor channel assembly resource.
-
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Retrieves information about the channels that are associated with the current AWS account.
-
#list_functions(params = {}) ⇒ Types::ListFunctionsResponse
Retrieves all functions associated with your AWS account in the current Region.
-
#list_live_sources(params = {}) ⇒ Types::ListLiveSourcesResponse
Lists the live sources contained in a source location.
-
#list_playback_configurations(params = {}) ⇒ Types::ListPlaybackConfigurationsResponse
Retrieves existing playback configurations.
-
#list_prefetch_schedules(params = {}) ⇒ Types::ListPrefetchSchedulesResponse
Lists the prefetch schedules for a playback configuration.
-
#list_source_locations(params = {}) ⇒ Types::ListSourceLocationsResponse
Lists the source locations for a channel.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags that are associated with this resource.
-
#list_vod_sources(params = {}) ⇒ Types::ListVodSourcesResponse
Lists the VOD sources contained in a source location.
-
#put_channel_policy(params = {}) ⇒ Struct
Creates an IAM policy for the channel.
-
#put_function(params = {}) ⇒ Types::PutFunctionResponse
Creates or updates a function.
-
#put_playback_configuration(params = {}) ⇒ Types::PutPlaybackConfigurationResponse
Creates a playback configuration.
-
#start_channel(params = {}) ⇒ Struct
Starts a channel.
-
#stop_channel(params = {}) ⇒ Struct
Stops a channel.
-
#tag_resource(params = {}) ⇒ Struct
The resource to tag.
-
#untag_resource(params = {}) ⇒ Struct
The resource to untag.
-
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel.
-
#update_live_source(params = {}) ⇒ Types::UpdateLiveSourceResponse
Updates a live source’s configuration.
-
#update_program(params = {}) ⇒ Types::UpdateProgramResponse
Updates a program within a channel.
-
#update_source_location(params = {}) ⇒ Types::UpdateSourceLocationResponse
Updates a source location.
-
#update_vod_source(params = {}) ⇒ Types::UpdateVodSourceResponse
Updates a VOD source’s configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4206 4207 4208 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 4206 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4209 4210 4211 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 4209 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 4179 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MediaTailor') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mediatailor' context[:gem_version] = '1.118.0' Seahorse::Client::Request.new(handlers, context) end |
#configure_logs_for_channel(params = {}) ⇒ Types::ConfigureLogsForChannelResponse
Configures Amazon CloudWatch log settings for a channel.
509 510 511 512 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 509 def configure_logs_for_channel(params = {}, = {}) req = build_request(:configure_logs_for_channel, params) req.send_request() end |
#configure_logs_for_playback_configuration(params = {}) ⇒ Types::ConfigureLogsForPlaybackConfigurationResponse
Defines where AWS Elemental MediaTailor sends logs for the playback configuration.
602 603 604 605 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 602 def configure_logs_for_playback_configuration(params = {}, = {}) req = build_request(:configure_logs_for_playback_configuration, params) req.send_request() end |
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a channel. For information about MediaTailor channels, see
- Working with channels][1
-
in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html
738 739 740 741 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 738 def create_channel(params = {}, = {}) req = build_request(:create_channel, params) req.send_request() end |
#create_live_source(params = {}) ⇒ Types::CreateLiveSourceResponse
The live source configuration.
809 810 811 812 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 809 def create_live_source(params = {}, = {}) req = build_request(:create_live_source, params) req.send_request() end |
#create_prefetch_schedule(params = {}) ⇒ Types::CreatePrefetchScheduleResponse
Creates a prefetch schedule for a playback configuration. A prefetch schedule allows you to tell MediaTailor to fetch and prepare certain ads before an ad break happens. For more information about ad prefetching, see [Using ad prefetching] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/prefetching-ads.html
994 995 996 997 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 994 def create_prefetch_schedule(params = {}, = {}) req = build_request(:create_prefetch_schedule, params) req.send_request() end |
#create_program(params = {}) ⇒ Types::CreateProgramResponse
Creates a program within a channel. For information about programs, see [Working with programs] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-programs.html
1244 1245 1246 1247 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1244 def create_program(params = {}, = {}) req = build_request(:create_program, params) req.send_request() end |
#create_source_location(params = {}) ⇒ Types::CreateSourceLocationResponse
Creates a source location. A source location is a container for sources. For more information about source locations, see [Working with source locations] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-source-locations.html
1347 1348 1349 1350 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1347 def create_source_location(params = {}, = {}) req = build_request(:create_source_location, params) req.send_request() end |
#create_vod_source(params = {}) ⇒ Types::CreateVodSourceResponse
The VOD source configuration parameters.
1418 1419 1420 1421 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1418 def create_vod_source(params = {}, = {}) req = build_request(:create_vod_source, params) req.send_request() end |
#delete_channel(params = {}) ⇒ Struct
Deletes a channel. For information about MediaTailor channels, see
- Working with channels][1
-
in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html
1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1445 def delete_channel(params = {}, = {}) req = build_request(:delete_channel, params) req.send_request() end |
#delete_channel_policy(params = {}) ⇒ Struct
The channel policy to delete.
1467 1468 1469 1470 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1467 def delete_channel_policy(params = {}, = {}) req = build_request(:delete_channel_policy, params) req.send_request() end |
#delete_function(params = {}) ⇒ Struct
Deletes a function. MediaTailor prevents deletion of a function that is still referenced by a playback configuration or by another function. Remove all references before deleting. For more information about functions, see [Working with functions] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/monetization-functions.html
1497 1498 1499 1500 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1497 def delete_function(params = {}, = {}) req = build_request(:delete_function, params) req.send_request() end |
#delete_live_source(params = {}) ⇒ Struct
The live source to delete.
1523 1524 1525 1526 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1523 def delete_live_source(params = {}, = {}) req = build_request(:delete_live_source, params) req.send_request() end |
#delete_playback_configuration(params = {}) ⇒ Struct
Deletes a playback configuration. For information about MediaTailor configurations, see [Working with configurations in AWS Elemental MediaTailor].
[1]: docs.aws.amazon.com/mediatailor/latest/ug/configurations.html
1551 1552 1553 1554 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1551 def delete_playback_configuration(params = {}, = {}) req = build_request(:delete_playback_configuration, params) req.send_request() end |
#delete_prefetch_schedule(params = {}) ⇒ Struct
Deletes a prefetch schedule for a specific playback configuration. If you call ‘DeletePrefetchSchedule` on an expired prefetch schedule, MediaTailor returns an HTTP 404 status code. For more information about ad prefetching, see [Using ad prefetching] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/prefetching-ads.html
1586 1587 1588 1589 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1586 def delete_prefetch_schedule(params = {}, = {}) req = build_request(:delete_prefetch_schedule, params) req.send_request() end |
#delete_program(params = {}) ⇒ Struct
Deletes a program within a channel. For information about programs, see [Working with programs] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-programs.html
1617 1618 1619 1620 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1617 def delete_program(params = {}, = {}) req = build_request(:delete_program, params) req.send_request() end |
#delete_source_location(params = {}) ⇒ Struct
Deletes a source location. A source location is a container for sources. For more information about source locations, see [Working with source locations] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-source-locations.html
1645 1646 1647 1648 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1645 def delete_source_location(params = {}, = {}) req = build_request(:delete_source_location, params) req.send_request() end |
#delete_vod_source(params = {}) ⇒ Struct
The video on demand (VOD) source to delete.
1671 1672 1673 1674 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1671 def delete_vod_source(params = {}, = {}) req = build_request(:delete_vod_source, params) req.send_request() end |
#describe_channel(params = {}) ⇒ Types::DescribeChannelResponse
Describes a channel. For information about MediaTailor channels, see
- Working with channels][1
-
in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html
1742 1743 1744 1745 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1742 def describe_channel(params = {}, = {}) req = build_request(:describe_channel, params) req.send_request() end |
#describe_live_source(params = {}) ⇒ Types::DescribeLiveSourceResponse
The live source to describe.
1790 1791 1792 1793 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1790 def describe_live_source(params = {}, = {}) req = build_request(:describe_live_source, params) req.send_request() end |
#describe_program(params = {}) ⇒ Types::DescribeProgramResponse
Describes a program within a channel. For information about programs, see [Working with programs] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-programs.html
1903 1904 1905 1906 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1903 def describe_program(params = {}, = {}) req = build_request(:describe_program, params) req.send_request() end |
#describe_source_location(params = {}) ⇒ Types::DescribeSourceLocationResponse
Describes a source location. A source location is a container for sources. For more information about source locations, see [Working with source locations] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-source-locations.html
1959 1960 1961 1962 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 1959 def describe_source_location(params = {}, = {}) req = build_request(:describe_source_location, params) req.send_request() end |
#describe_vod_source(params = {}) ⇒ Types::DescribeVodSourceResponse
Provides details about a specific video on demand (VOD) source in a specific source location.
2011 2012 2013 2014 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2011 def describe_vod_source(params = {}, = {}) req = build_request(:describe_vod_source, params) req.send_request() end |
#get_channel_policy(params = {}) ⇒ Types::GetChannelPolicyResponse
Returns the channel’s IAM policy. IAM policies are used to control access to your channel.
2040 2041 2042 2043 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2040 def get_channel_policy(params = {}, = {}) req = build_request(:get_channel_policy, params) req.send_request() end |
#get_channel_schedule(params = {}) ⇒ Types::GetChannelScheduleResponse
Retrieves information about your channel’s schedule.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2118 2119 2120 2121 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2118 def get_channel_schedule(params = {}, = {}) req = build_request(:get_channel_schedule, params) req.send_request() end |
#get_function(params = {}) ⇒ Types::GetFunctionResponse
Retrieves the configuration and metadata for a function. For more information about functions, see [Working with functions] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/monetization-functions.html
2183 2184 2185 2186 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2183 def get_function(params = {}, = {}) req = build_request(:get_function, params) req.send_request() end |
#get_playback_configuration(params = {}) ⇒ Types::GetPlaybackConfigurationResponse
Retrieves a playback configuration. For information about MediaTailor configurations, see [Working with configurations in AWS Elemental MediaTailor].
[1]: docs.aws.amazon.com/mediatailor/latest/ug/configurations.html
2286 2287 2288 2289 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2286 def get_playback_configuration(params = {}, = {}) req = build_request(:get_playback_configuration, params) req.send_request() end |
#get_prefetch_schedule(params = {}) ⇒ Types::GetPrefetchScheduleResponse
Retrieves a prefetch schedule for a playback configuration. A prefetch schedule allows you to tell MediaTailor to fetch and prepare certain ads before an ad break happens. For more information about ad prefetching, see [Using ad prefetching] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/prefetching-ads.html
2371 2372 2373 2374 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2371 def get_prefetch_schedule(params = {}, = {}) req = build_request(:get_prefetch_schedule, params) req.send_request() end |
#list_alerts(params = {}) ⇒ Types::ListAlertsResponse
Lists the alerts that are associated with a MediaTailor channel assembly resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2436 2437 2438 2439 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2436 def list_alerts(params = {}, = {}) req = build_request(:list_alerts, params) req.send_request() end |
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Retrieves information about the channels that are associated with the current AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2516 2517 2518 2519 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2516 def list_channels(params = {}, = {}) req = build_request(:list_channels, params) req.send_request() end |
#list_functions(params = {}) ⇒ Types::ListFunctionsResponse
Retrieves all functions associated with your AWS account in the current Region. For more information about functions, see [Working with functions] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/monetization-functions.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2600 2601 2602 2603 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2600 def list_functions(params = {}, = {}) req = build_request(:list_functions, params) req.send_request() end |
#list_live_sources(params = {}) ⇒ Types::ListLiveSourcesResponse
Lists the live sources contained in a source location. A source represents a piece of content.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2671 2672 2673 2674 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2671 def list_live_sources(params = {}, = {}) req = build_request(:list_live_sources, params) req.send_request() end |
#list_playback_configurations(params = {}) ⇒ Types::ListPlaybackConfigurationsResponse
Retrieves existing playback configurations. For information about MediaTailor configurations, see [Working with Configurations in AWS Elemental MediaTailor].
[1]: docs.aws.amazon.com/mediatailor/latest/ug/configurations.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2779 2780 2781 2782 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2779 def list_playback_configurations(params = {}, = {}) req = build_request(:list_playback_configurations, params) req.send_request() end |
#list_prefetch_schedules(params = {}) ⇒ Types::ListPrefetchSchedulesResponse
Lists the prefetch schedules for a playback configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2884 2885 2886 2887 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2884 def list_prefetch_schedules(params = {}, = {}) req = build_request(:list_prefetch_schedules, params) req.send_request() end |
#list_source_locations(params = {}) ⇒ Types::ListSourceLocationsResponse
Lists the source locations for a channel. A source location defines the host server URL, and contains a list of sources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2954 2955 2956 2957 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2954 def list_source_locations(params = {}, = {}) req = build_request(:list_source_locations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of tags that are associated with this resource. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see [Tagging AWS Elemental MediaTailor Resources].
2990 2991 2992 2993 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 2990 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_vod_sources(params = {}) ⇒ Types::ListVodSourcesResponse
Lists the VOD sources contained in a source location. A source represents a piece of content.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3060 3061 3062 3063 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3060 def list_vod_sources(params = {}, = {}) req = build_request(:list_vod_sources, params) req.send_request() end |
#put_channel_policy(params = {}) ⇒ Struct
Creates an IAM policy for the channel. IAM policies are used to control access to your channel.
3087 3088 3089 3090 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3087 def put_channel_policy(params = {}, = {}) req = build_request(:put_channel_policy, params) req.send_request() end |
#put_function(params = {}) ⇒ Types::PutFunctionResponse
Creates or updates a function. A function defines reusable logic that MediaTailor executes at lifecycle hooks during ad insertion. For more information about functions, see [Working with functions] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/monetization-functions.html
3234 3235 3236 3237 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3234 def put_function(params = {}, = {}) req = build_request(:put_function, params) req.send_request() end |
#put_playback_configuration(params = {}) ⇒ Types::PutPlaybackConfigurationResponse
Creates a playback configuration. For information about MediaTailor configurations, see [Working with configurations in AWS Elemental MediaTailor].
[1]: docs.aws.amazon.com/mediatailor/latest/ug/configurations.html
3515 3516 3517 3518 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3515 def put_playback_configuration(params = {}, = {}) req = build_request(:put_playback_configuration, params) req.send_request() end |
#start_channel(params = {}) ⇒ Struct
Starts a channel. For information about MediaTailor channels, see
- Working with channels][1
-
in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html
3542 3543 3544 3545 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3542 def start_channel(params = {}, = {}) req = build_request(:start_channel, params) req.send_request() end |
#stop_channel(params = {}) ⇒ Struct
Stops a channel. For information about MediaTailor channels, see
- Working with channels][1
-
in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html
3569 3570 3571 3572 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3569 def stop_channel(params = {}, = {}) req = build_request(:stop_channel, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
The resource to tag. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see [Tagging AWS Elemental MediaTailor Resources].
3611 3612 3613 3614 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3611 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
The resource to untag.
3637 3638 3639 3640 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3637 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel. For information about MediaTailor channels, see
- Working with channels][1
-
in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-channels.html
3745 3746 3747 3748 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3745 def update_channel(params = {}, = {}) req = build_request(:update_channel, params) req.send_request() end |
#update_live_source(params = {}) ⇒ Types::UpdateLiveSourceResponse
Updates a live source’s configuration.
3804 3805 3806 3807 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 3804 def update_live_source(params = {}, = {}) req = build_request(:update_live_source, params) req.send_request() end |
#update_program(params = {}) ⇒ Types::UpdateProgramResponse
Updates a program within a channel.
4021 4022 4023 4024 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 4021 def update_program(params = {}, = {}) req = build_request(:update_program, params) req.send_request() end |
#update_source_location(params = {}) ⇒ Types::UpdateSourceLocationResponse
Updates a source location. A source location is a container for sources. For more information about source locations, see [Working with source locations] in the *MediaTailor User Guide*.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-source-locations.html
4111 4112 4113 4114 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 4111 def update_source_location(params = {}, = {}) req = build_request(:update_source_location, params) req.send_request() end |
#update_vod_source(params = {}) ⇒ Types::UpdateVodSourceResponse
Updates a VOD source’s configuration.
4170 4171 4172 4173 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 4170 def update_vod_source(params = {}, = {}) req = build_request(:update_vod_source, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4199 4200 4201 |
# File 'lib/aws-sdk-mediatailor/client.rb', line 4199 def waiter_names [] end |