Class: Aws::MediaTailor::Types::AvailSuppression

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

The configuration for avail suppression, also known as ad suppression. For more information about ad suppression, see Ad Suppression.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fill_policyString

Defines the policy to apply to the avail suppression mode. BEHIND_LIVE_EDGE will always use the full avail suppression policy. AFTER_LIVE_EDGE mode can be used to invoke partial ad break fills when a session starts mid-break.



535
536
537
538
539
540
541
# File 'lib/aws-sdk-mediatailor/types.rb', line 535

class AvailSuppression < Struct.new(
  :mode,
  :value,
  :fill_policy)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

Sets the ad suppression mode. By default, ad suppression is off and all ad breaks are filled with ads or slate. When Mode is set to BEHIND_LIVE_EDGE, ad suppression is active and MediaTailor won't fill ad breaks on or behind the ad suppression Value time in the manifest lookback window. When Mode is set to AFTER_LIVE_EDGE, ad suppression is active and MediaTailor won't fill ad breaks that are within the live edge plus the avail suppression value.



535
536
537
538
539
540
541
# File 'lib/aws-sdk-mediatailor/types.rb', line 535

class AvailSuppression < Struct.new(
  :mode,
  :value,
  :fill_policy)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

A live edge offset time in HH:MM:SS. MediaTailor won't fill ad breaks on or behind this time in the manifest lookback window. If Value is set to 00:00:00, it is in sync with the live edge, and MediaTailor won't fill any ad breaks on or behind the live edge. If you set a Value time, MediaTailor won't fill any ad breaks on or behind this time in the manifest lookback window. For example, if you set 00:45:00, then MediaTailor will fill ad breaks that occur within 45 minutes behind the live edge, but won't fill ad breaks on or behind 45 minutes behind the live edge.



535
536
537
538
539
540
541
# File 'lib/aws-sdk-mediatailor/types.rb', line 535

class AvailSuppression < Struct.new(
  :mode,
  :value,
  :fill_policy)
  SENSITIVE = []
  include Aws::Structure
end