Class: Aws::MediaTailor::Types::AwsServiceRequestConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

The configuration for an AWS_SERVICE_REQUEST function. Contains the target service, target Region, and request parameters that the function uses to call an AWS service API. For more information, see AWS_SERVICE_REQUEST in the MediaTailor User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bodyString

An expression that evaluates to the request body for the AWS service API call. The body must conform to the input format that the target service operation expects. Applies only when the target operation accepts a request body. The maximum size after evaluation is 64 KB.

Returns:

  • (String)


622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/aws-sdk-mediatailor/types.rb', line 622

class AwsServiceRequestConfiguration < Struct.new(
  :runtime,
  :output,
  :method_type,
  :request_timeout_milliseconds,
  :url,
  :body,
  :headers,
  :target_service,
  :target_region)
  SENSITIVE = []
  include Aws::Structure
end

#headersHash<String,String>

A map of HTTP header names to expression values. MediaTailor evaluates each header value expression at runtime and includes the result in the outbound request to the AWS service. Use this to pass any headers required by the target service operation. You can include a maximum of 50 headers.

Returns:

  • (Hash<String,String>)


622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/aws-sdk-mediatailor/types.rb', line 622

class AwsServiceRequestConfiguration < Struct.new(
  :runtime,
  :output,
  :method_type,
  :request_timeout_milliseconds,
  :url,
  :body,
  :headers,
  :target_service,
  :target_region)
  SENSITIVE = []
  include Aws::Structure
end

#method_typeString

Specifies how the function sends the request to the target service. The value must match what the target service operation requires. Valid values:

  • GET – Retrieves data from the target service.

  • POST – Submits a request body to the target service.

Returns:

  • (String)


622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/aws-sdk-mediatailor/types.rb', line 622

class AwsServiceRequestConfiguration < Struct.new(
  :runtime,
  :output,
  :method_type,
  :request_timeout_milliseconds,
  :url,
  :body,
  :headers,
  :target_service,
  :target_region)
  SENSITIVE = []
  include Aws::Structure
end

#outputHash<String,String>

A map of output bindings. Each key is a namespaced output path, such as player_params.device_type. Each value is an expression that MediaTailor evaluates at runtime and can reference the response object from the target service. For more information, see JSONata expression reference in the MediaTailor User Guide.

Returns:

  • (Hash<String,String>)


622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/aws-sdk-mediatailor/types.rb', line 622

class AwsServiceRequestConfiguration < Struct.new(
  :runtime,
  :output,
  :method_type,
  :request_timeout_milliseconds,
  :url,
  :body,
  :headers,
  :target_service,
  :target_region)
  SENSITIVE = []
  include Aws::Structure
end

#request_timeout_millisecondsInteger

The maximum time, in milliseconds, that MediaTailor waits for a response from the AWS service. If the call exceeds this timeout, MediaTailor sets the response status code to null and proceeds with output expression evaluation. Valid values: 100 to 2000.

Returns:

  • (Integer)


622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/aws-sdk-mediatailor/types.rb', line 622

class AwsServiceRequestConfiguration < Struct.new(
  :runtime,
  :output,
  :method_type,
  :request_timeout_milliseconds,
  :url,
  :body,
  :headers,
  :target_service,
  :target_region)
  SENSITIVE = []
  include Aws::Structure
end

#runtimeString

The expression language used to evaluate expressions in the function configuration. The only supported value is JSONata.

Returns:

  • (String)


622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/aws-sdk-mediatailor/types.rb', line 622

class AwsServiceRequestConfiguration < Struct.new(
  :runtime,
  :output,
  :method_type,
  :request_timeout_milliseconds,
  :url,
  :body,
  :headers,
  :target_service,
  :target_region)
  SENSITIVE = []
  include Aws::Structure
end

#target_regionString

The AWS Region for the target service. Specify a static Region code (for example, us-east-1) or a JSONata expression that resolves to a Region code at runtime (for example, {%inference.region%}).

Returns:

  • (String)


622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/aws-sdk-mediatailor/types.rb', line 622

class AwsServiceRequestConfiguration < Struct.new(
  :runtime,
  :output,
  :method_type,
  :request_timeout_milliseconds,
  :url,
  :body,
  :headers,
  :target_service,
  :target_region)
  SENSITIVE = []
  include Aws::Structure
end

#target_serviceString

The AWS service to call. Valid value: elemental-inference (AWS Elemental Inference).

Returns:

  • (String)


622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/aws-sdk-mediatailor/types.rb', line 622

class AwsServiceRequestConfiguration < Struct.new(
  :runtime,
  :output,
  :method_type,
  :request_timeout_milliseconds,
  :url,
  :body,
  :headers,
  :target_service,
  :target_region)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

An expression that evaluates to the endpoint URL for the target AWS service API operation. Use {%...%} delimiters for dynamic expressions. The URL must correspond to a valid endpoint for the service specified in TargetService. The maximum length after evaluation is 2,048 characters.

Returns:

  • (String)


622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/aws-sdk-mediatailor/types.rb', line 622

class AwsServiceRequestConfiguration < Struct.new(
  :runtime,
  :output,
  :method_type,
  :request_timeout_milliseconds,
  :url,
  :body,
  :headers,
  :target_service,
  :target_region)
  SENSITIVE = []
  include Aws::Structure
end