Class: Aws::MediaTailor::Types::Bumper
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::Bumper
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
The configuration for bumpers. Bumpers are short audio or video clips that play at the start or before the end of an ad break. To learn more about bumpers, see Bumpers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_url ⇒ String
The URL for the end bumper asset.
-
#start_url ⇒ String
The URL for the start bumper asset.
Instance Attribute Details
#end_url ⇒ String
The URL for the end bumper asset.
667 668 669 670 671 672 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 667 class Bumper < Struct.new( :end_url, :start_url) SENSITIVE = [] include Aws::Structure end |
#start_url ⇒ String
The URL for the start bumper asset.
667 668 669 670 671 672 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 667 class Bumper < Struct.new( :end_url, :start_url) SENSITIVE = [] include Aws::Structure end |