Class: Aws::MediaTailor::Types::Channel
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::Channel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
The configuration parameters for a channel. For information about MediaTailor channels, see Working with channels in the MediaTailor User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the channel.
-
#audiences ⇒ Array<String>
The list of audiences defined in channel.
-
#channel_name ⇒ String
The name of the channel.
-
#channel_state ⇒ String
Returns the state whether the channel is running or not.
-
#creation_time ⇒ Time
The timestamp of when the channel was created.
-
#filler_slate ⇒ Types::SlateSource
The slate used to fill gaps between programs in the schedule.
-
#last_modified_time ⇒ Time
The timestamp of when the channel was last modified.
-
#log_configuration ⇒ Types::LogConfigurationForChannel
The log configuration.
-
#outputs ⇒ Array<Types::ResponseOutputItem>
The channel's output properties.
-
#playback_mode ⇒ String
The type of playback mode for this channel.
-
#tags ⇒ Hash<String,String>
The tags to assign to the channel.
-
#tier ⇒ String
The tier for this channel.
Instance Attribute Details
#arn ⇒ String
The ARN of the channel.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#audiences ⇒ Array<String>
The list of audiences defined in channel.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#channel_state ⇒ String
Returns the state whether the channel is running or not.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp of when the channel was created.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#filler_slate ⇒ Types::SlateSource
The slate used to fill gaps between programs in the schedule. You
must configure filler slate if your channel uses the LINEAR
PlaybackMode. MediaTailor doesn't support filler slate for
channels using the LOOP PlaybackMode.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp of when the channel was last modified.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#log_configuration ⇒ Types::LogConfigurationForChannel
The log configuration.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::ResponseOutputItem>
The channel's output properties.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#playback_mode ⇒ String
The type of playback mode for this channel.
LINEAR - Programs play back-to-back only once.
LOOP - Programs play back-to-back in an endless loop. When the
last program in the schedule plays, playback loops back to the first
program in the schedule.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the channel. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
The tier for this channel. STANDARD tier channels can contain live programs.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 781 class Channel < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :log_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |