Class: Aws::MediaTailor::Types::CreateChannelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::CreateChannelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) to assign to the channel.
-
#audiences ⇒ Array<String>
The list of audiences defined in channel.
-
#channel_name ⇒ String
The name to assign to the channel.
-
#channel_state ⇒ String
Indicates whether the channel is in a running state or not.
-
#creation_time ⇒ Time
The timestamp of when the channel was created.
-
#filler_slate ⇒ Types::SlateSource
Contains information about the slate used to fill gaps between programs in the schedule.
-
#last_modified_time ⇒ Time
The timestamp of when the channel was last modified.
-
#outputs ⇒ Array<Types::ResponseOutputItem>
The output properties to assign to the channel.
-
#playback_mode ⇒ String
The playback mode to assign to the channel.
-
#tags ⇒ Hash<String,String>
The tags to assign to the channel.
-
#tier ⇒ String
The tier of the channel.
-
#time_shift_configuration ⇒ Types::TimeShiftConfiguration
The time-shifted viewing configuration assigned to the channel.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) to assign to the channel.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#audiences ⇒ Array<String>
The list of audiences defined in channel.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name to assign to the channel.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#channel_state ⇒ String
Indicates whether the channel is in a running state or not.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp of when the channel was created.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#filler_slate ⇒ Types::SlateSource
Contains information about the slate used to fill gaps between programs in the schedule.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp of when the channel was last modified.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::ResponseOutputItem>
The output properties to assign to the channel.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#playback_mode ⇒ String
The playback mode to assign to the channel.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the channel. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
The tier of the channel.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#time_shift_configuration ⇒ Types::TimeShiftConfiguration
The time-shifted viewing configuration assigned to the channel.
1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1137 class CreateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |