Class: Aws::MediaTailor::Types::CreateLiveSourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::CreateLiveSourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configuration parameters for this live source.
-
#live_source_name ⇒ String
The name of the live source.
-
#source_location_name ⇒ String
The name of the source location.
-
#tags ⇒ Hash<String,String>
The tags to assign to the live source.
Instance Attribute Details
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configuration parameters for this live source.
1180 1181 1182 1183 1184 1185 1186 1187 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1180 class CreateLiveSourceRequest < Struct.new( :http_package_configurations, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#live_source_name ⇒ String
The name of the live source.
1180 1181 1182 1183 1184 1185 1186 1187 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1180 class CreateLiveSourceRequest < Struct.new( :http_package_configurations, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location.
1180 1181 1182 1183 1184 1185 1186 1187 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1180 class CreateLiveSourceRequest < Struct.new( :http_package_configurations, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the live source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
1180 1181 1182 1183 1184 1185 1186 1187 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1180 class CreateLiveSourceRequest < Struct.new( :http_package_configurations, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |