Class: Aws::MediaTailor::Types::CreateLiveSourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::CreateLiveSourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN to assign to the live source.
-
#creation_time ⇒ Time
The time the live source was created.
-
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configuration parameters for this live source.
-
#last_modified_time ⇒ Time
The time the live source was last modified.
-
#live_source_name ⇒ String
The name to assign to the live source.
-
#source_location_name ⇒ String
The name to assign to the source location of the live source.
-
#tags ⇒ Hash<String,String>
The tags to assign to the live source.
Instance Attribute Details
#arn ⇒ String
The ARN to assign to the live source.
1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1227 class CreateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time the live source was created.
1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1227 class CreateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configuration parameters for this live source.
1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1227 class CreateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time the live source was last modified.
1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1227 class CreateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#live_source_name ⇒ String
The name to assign to the live source.
1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1227 class CreateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name to assign to the source location of the live source.
1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1227 class CreateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the live source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1227 class CreateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |