Class: Aws::MediaTailor::Types::CreatePrefetchScheduleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumptionTypes::PrefetchConsumption

The configuration settings for how and when MediaTailor consumes prefetched ads from the ad decision server for single prefetch schedules. Each consumption configuration contains an end time and an optional start time that define the *consumption window*. Prefetch schedules automatically expire no earlier than seven days after the end time.



1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
# File 'lib/aws-sdk-mediatailor/types.rb', line 1059

class CreatePrefetchScheduleRequest < Struct.new(
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :recurring_prefetch_configuration,
  :schedule_type,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name to assign to the schedule request.

Returns:

  • (String)


1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
# File 'lib/aws-sdk-mediatailor/types.rb', line 1059

class CreatePrefetchScheduleRequest < Struct.new(
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :recurring_prefetch_configuration,
  :schedule_type,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#playback_configuration_nameString

The name to assign to the playback configuration.

Returns:

  • (String)


1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
# File 'lib/aws-sdk-mediatailor/types.rb', line 1059

class CreatePrefetchScheduleRequest < Struct.new(
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :recurring_prefetch_configuration,
  :schedule_type,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#recurring_prefetch_configurationTypes::RecurringPrefetchConfiguration

The configuration that defines how and when MediaTailor performs ad prefetching in a live event.



1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
# File 'lib/aws-sdk-mediatailor/types.rb', line 1059

class CreatePrefetchScheduleRequest < Struct.new(
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :recurring_prefetch_configuration,
  :schedule_type,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#retrievalTypes::PrefetchRetrieval

The configuration settings for retrieval of prefetched ads from the ad decision server. Only one set of prefetched ads will be retrieved and subsequently consumed for each ad break.



1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
# File 'lib/aws-sdk-mediatailor/types.rb', line 1059

class CreatePrefetchScheduleRequest < Struct.new(
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :recurring_prefetch_configuration,
  :schedule_type,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_typeString

The frequency that MediaTailor creates prefetch schedules. SINGLE indicates that this schedule applies to one ad break. RECURRING indicates that MediaTailor automatically creates a schedule for each ad avail in a live event.

For more information about the prefetch types and when you might use each, see [Prefetching ads in Elemental MediaTailor.]

[1]: docs.aws.amazon.com/mediatailor/latest/ug/prefetching-ads.html

Returns:

  • (String)


1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
# File 'lib/aws-sdk-mediatailor/types.rb', line 1059

class CreatePrefetchScheduleRequest < Struct.new(
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :recurring_prefetch_configuration,
  :schedule_type,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

An optional stream identifier that MediaTailor uses to prefetch ads for multiple streams that use the same playback configuration. If StreamId is specified, MediaTailor returns all of the prefetch schedules with an exact match on StreamId. If not specified, MediaTailor returns all of the prefetch schedules for the playback configuration, regardless of StreamId.

Returns:

  • (String)


1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
# File 'lib/aws-sdk-mediatailor/types.rb', line 1059

class CreatePrefetchScheduleRequest < Struct.new(
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :recurring_prefetch_configuration,
  :schedule_type,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end