Class: Aws::MediaTailor::Types::CreateProgramRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::CreateProgramRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_breaks ⇒ Array<Types::AdBreak>
The ad break configuration settings.
-
#audience_media ⇒ Array<Types::AudienceMedia>
The list of AudienceMedia defined in program.
-
#channel_name ⇒ String
The name of the channel for this Program.
-
#live_source_name ⇒ String
The name of the LiveSource for this Program.
-
#program_name ⇒ String
The name of the Program.
-
#schedule_configuration ⇒ Types::ScheduleConfiguration
The schedule configuration settings.
-
#source_location_name ⇒ String
The name of the source location.
-
#tags ⇒ Hash<String,String>
The tags to assign to the program.
-
#vod_source_name ⇒ String
The name that's used to refer to a VOD source.
Instance Attribute Details
#ad_breaks ⇒ Array<Types::AdBreak>
The ad break configuration settings.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1436 class CreateProgramRequest < Struct.new( :ad_breaks, :channel_name, :live_source_name, :program_name, :schedule_configuration, :source_location_name, :vod_source_name, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#audience_media ⇒ Array<Types::AudienceMedia>
The list of AudienceMedia defined in program.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1436 class CreateProgramRequest < Struct.new( :ad_breaks, :channel_name, :live_source_name, :program_name, :schedule_configuration, :source_location_name, :vod_source_name, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel for this Program.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1436 class CreateProgramRequest < Struct.new( :ad_breaks, :channel_name, :live_source_name, :program_name, :schedule_configuration, :source_location_name, :vod_source_name, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#live_source_name ⇒ String
The name of the LiveSource for this Program.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1436 class CreateProgramRequest < Struct.new( :ad_breaks, :channel_name, :live_source_name, :program_name, :schedule_configuration, :source_location_name, :vod_source_name, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#program_name ⇒ String
The name of the Program.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1436 class CreateProgramRequest < Struct.new( :ad_breaks, :channel_name, :live_source_name, :program_name, :schedule_configuration, :source_location_name, :vod_source_name, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#schedule_configuration ⇒ Types::ScheduleConfiguration
The schedule configuration settings.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1436 class CreateProgramRequest < Struct.new( :ad_breaks, :channel_name, :live_source_name, :program_name, :schedule_configuration, :source_location_name, :vod_source_name, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1436 class CreateProgramRequest < Struct.new( :ad_breaks, :channel_name, :live_source_name, :program_name, :schedule_configuration, :source_location_name, :vod_source_name, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the program. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1436 class CreateProgramRequest < Struct.new( :ad_breaks, :channel_name, :live_source_name, :program_name, :schedule_configuration, :source_location_name, :vod_source_name, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#vod_source_name ⇒ String
The name that's used to refer to a VOD source.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1436 class CreateProgramRequest < Struct.new( :ad_breaks, :channel_name, :live_source_name, :program_name, :schedule_configuration, :source_location_name, :vod_source_name, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |