Class: Aws::MediaTailor::Types::CreateProgramResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ad_breaksArray<Types::AdBreak>

The ad break configuration settings.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN to assign to the program.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#audience_mediaArray<Types::AudienceMedia>

The list of AudienceMedia defined in program.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name to assign to the channel for this program.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#clip_rangeTypes::ClipRange

The clip range configuration settings.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time the program was created.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#duration_millisInteger

The duration of the live program in milliseconds.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#live_source_nameString

The name of the LiveSource for this Program.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#program_nameString

The name to assign to this program.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_start_timeTime

The scheduled start time for this Program.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#source_location_nameString

The name to assign to the source location for this program.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags assigned to the program. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vod_source_nameString

The name that's used to refer to a VOD source.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511

class CreateProgramResponse < Struct.new(
  :ad_breaks,
  :arn,
  :channel_name,
  :creation_time,
  :live_source_name,
  :program_name,
  :scheduled_start_time,
  :source_location_name,
  :vod_source_name,
  :clip_range,
  :duration_millis,
  :audience_media,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end