Class: Aws::MediaTailor::Types::CreateSourceLocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::CreateSourceLocationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_configuration ⇒ Types::AccessConfiguration
Access configuration parameters.
-
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The optional configuration for the server that serves segments.
-
#http_configuration ⇒ Types::HttpConfiguration
The source's HTTP package configurations.
-
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
A list of the segment delivery configurations associated with this resource.
-
#source_location_name ⇒ String
The name associated with the source location.
-
#tags ⇒ Hash<String,String>
The tags to assign to the source location.
Instance Attribute Details
#access_configuration ⇒ Types::AccessConfiguration
Access configuration parameters. Configures the type of authentication used to access content from your source location.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1564 class CreateSourceLocationRequest < Struct.new( :access_configuration, :default_segment_delivery_configuration, :http_configuration, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The optional configuration for the server that serves segments.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1564 class CreateSourceLocationRequest < Struct.new( :access_configuration, :default_segment_delivery_configuration, :http_configuration, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#http_configuration ⇒ Types::HttpConfiguration
The source's HTTP package configurations.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1564 class CreateSourceLocationRequest < Struct.new( :access_configuration, :default_segment_delivery_configuration, :http_configuration, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
A list of the segment delivery configurations associated with this resource.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1564 class CreateSourceLocationRequest < Struct.new( :access_configuration, :default_segment_delivery_configuration, :http_configuration, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name associated with the source location.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1564 class CreateSourceLocationRequest < Struct.new( :access_configuration, :default_segment_delivery_configuration, :http_configuration, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the source location. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1564 class CreateSourceLocationRequest < Struct.new( :access_configuration, :default_segment_delivery_configuration, :http_configuration, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |