Class: Aws::MediaTailor::Types::CreateVodSourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#http_package_configurationsArray<Types::HttpPackageConfiguration>

A list of HTTP package configuration parameters for this VOD source.



1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-mediatailor/types.rb', line 1666

class CreateVodSourceRequest < Struct.new(
  :http_package_configurations,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#source_location_nameString

The name of the source location for this VOD source.

Returns:

  • (String)


1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-mediatailor/types.rb', line 1666

class CreateVodSourceRequest < Struct.new(
  :http_package_configurations,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to assign to the VOD source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Returns:

  • (Hash<String,String>)


1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-mediatailor/types.rb', line 1666

class CreateVodSourceRequest < Struct.new(
  :http_package_configurations,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#vod_source_nameString

The name associated with the VOD source.>

Returns:

  • (String)


1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-mediatailor/types.rb', line 1666

class CreateVodSourceRequest < Struct.new(
  :http_package_configurations,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end