Class: Aws::MediaTailor::Types::CreateVodSourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::CreateVodSourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN to assign to this VOD source.
-
#creation_time ⇒ Time
The time the VOD source was created.
-
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configuration parameters for this VOD source.
-
#last_modified_time ⇒ Time
The time the VOD source was last modified.
-
#source_location_name ⇒ String
The name to assign to the source location for this VOD source.
-
#tags ⇒ Hash<String,String>
The tags to assign to the VOD source.
-
#vod_source_name ⇒ String
The name to assign to the VOD source.
Instance Attribute Details
#arn ⇒ String
The ARN to assign to this VOD source.
1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1712 class CreateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time the VOD source was created.
1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1712 class CreateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configuration parameters for this VOD source.
1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1712 class CreateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time the VOD source was last modified.
1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1712 class CreateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name to assign to the source location for this VOD source.
1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1712 class CreateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the VOD source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1712 class CreateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#vod_source_name ⇒ String
The name to assign to the VOD source.
1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1712 class CreateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |