Class: Aws::MediaTailor::Types::CustomOutputConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

The configuration for a CUSTOM_OUTPUT function. MediaTailor evaluates the output expressions against the current session state and commits the results as output bindings. CUSTOM_OUTPUT functions do not make external calls. For more information, see CUSTOM_OUTPUT in the MediaTailor User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#outputHash<String,String>

A map of output bindings. Each key is a namespaced output path (such as player_params.device_type or temp.variant), and each value is an expression that MediaTailor evaluates at runtime against the current session state. For more information about expression syntax, see JSONata expression reference in the MediaTailor User Guide.

Returns:

  • (Hash<String,String>)


1754
1755
1756
1757
1758
1759
# File 'lib/aws-sdk-mediatailor/types.rb', line 1754

class CustomOutputConfiguration < Struct.new(
  :runtime,
  :output)
  SENSITIVE = []
  include Aws::Structure
end

#runtimeString

The expression language used to evaluate expressions in the function configuration. Set this to JSONata.

Returns:

  • (String)


1754
1755
1756
1757
1758
1759
# File 'lib/aws-sdk-mediatailor/types.rb', line 1754

class CustomOutputConfiguration < Struct.new(
  :runtime,
  :output)
  SENSITIVE = []
  include Aws::Structure
end