Class: Aws::MediaTailor::Types::DashConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

The configuration for DASH content.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dual_stack_manifest_endpoint_prefixString

The dual-stack (IPv4 and IPv6) URL that MediaTailor generates to initiate a playback session. The session uses server-side reporting.



1796
1797
1798
1799
1800
1801
1802
1803
# File 'lib/aws-sdk-mediatailor/types.rb', line 1796

class DashConfiguration < Struct.new(
  :manifest_endpoint_prefix,
  :dual_stack_manifest_endpoint_prefix,
  :mpd_location,
  :origin_manifest_type)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_endpoint_prefixString

The URL that MediaTailor generates to initiate a playback session. The session uses server-side reporting.



1796
1797
1798
1799
1800
1801
1802
1803
# File 'lib/aws-sdk-mediatailor/types.rb', line 1796

class DashConfiguration < Struct.new(
  :manifest_endpoint_prefix,
  :dual_stack_manifest_endpoint_prefix,
  :mpd_location,
  :origin_manifest_type)
  SENSITIVE = []
  include Aws::Structure
end

#mpd_locationString

The setting that controls whether MediaTailor includes the Location tag in DASH manifests. MediaTailor populates the Location tag with the URL for manifest update requests, to be used by players that don't support sticky redirects. Disable this if you have CDN routing rules set up for accessing MediaTailor manifests, and you are either using client-side reporting or your players support sticky HTTP redirects. Valid values are DISABLED and EMT_DEFAULT. The EMT_DEFAULT setting enables the inclusion of the tag and is the default value.



1796
1797
1798
1799
1800
1801
1802
1803
# File 'lib/aws-sdk-mediatailor/types.rb', line 1796

class DashConfiguration < Struct.new(
  :manifest_endpoint_prefix,
  :dual_stack_manifest_endpoint_prefix,
  :mpd_location,
  :origin_manifest_type)
  SENSITIVE = []
  include Aws::Structure
end

#origin_manifest_typeString

The setting that controls whether MediaTailor handles manifests from the origin server as multi-period manifests or single-period manifests. If your origin server produces single-period manifests, set this to SINGLE_PERIOD. The default setting is MULTI_PERIOD. For multi-period manifests, omit this setting or set it to MULTI_PERIOD.



1796
1797
1798
1799
1800
1801
1802
1803
# File 'lib/aws-sdk-mediatailor/types.rb', line 1796

class DashConfiguration < Struct.new(
  :manifest_endpoint_prefix,
  :dual_stack_manifest_endpoint_prefix,
  :mpd_location,
  :origin_manifest_type)
  SENSITIVE = []
  include Aws::Structure
end