Class: Aws::MediaTailor::Types::DefaultSegmentDeliveryConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::DefaultSegmentDeliveryConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
The optional configuration for a server that serves segments. Use this if you want the segment delivery server to be different from the source location server. For example, you can configure your source location server to be an origination server, such as MediaPackage, and the segment delivery server to be a content delivery network (CDN), such as CloudFront. If you don't specify a segment delivery server, then the source location server is used.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_url ⇒ String
The hostname of the server that will be used to serve segments.
Instance Attribute Details
#base_url ⇒ String
The hostname of the server that will be used to serve segments. This string must include the protocol, such as https://.
1888 1889 1890 1891 1892 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1888 class DefaultSegmentDeliveryConfiguration < Struct.new( :base_url) SENSITIVE = [] include Aws::Structure end |