Class: Aws::MediaTailor::Types::DeletePrefetchScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::DeletePrefetchScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the prefetch schedule.
-
#playback_configuration_name ⇒ String
The name of the playback configuration for this prefetch schedule.
Instance Attribute Details
#name ⇒ String
The name of the prefetch schedule. If the action is successful, the service sends back an HTTP 204 response with an empty HTTP body.
1990 1991 1992 1993 1994 1995 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1990 class DeletePrefetchScheduleRequest < Struct.new( :name, :playback_configuration_name) SENSITIVE = [] include Aws::Structure end |
#playback_configuration_name ⇒ String
The name of the playback configuration for this prefetch schedule.
1990 1991 1992 1993 1994 1995 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1990 class DeletePrefetchScheduleRequest < Struct.new( :name, :playback_configuration_name) SENSITIVE = [] include Aws::Structure end |