Class: Aws::MediaTailor::Types::DescribeLiveSourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::DescribeLiveSourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the live source.
-
#creation_time ⇒ Time
The timestamp that indicates when the live source was created.
-
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
The HTTP package configurations.
-
#last_modified_time ⇒ Time
The timestamp that indicates when the live source was modified.
-
#live_source_name ⇒ String
The name of the live source.
-
#source_location_name ⇒ String
The name of the source location associated with the live source.
-
#tags ⇒ Hash<String,String>
The tags assigned to the live source.
Instance Attribute Details
#arn ⇒ String
The ARN of the live source.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2205 class DescribeLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp that indicates when the live source was created.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2205 class DescribeLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
The HTTP package configurations.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2205 class DescribeLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp that indicates when the live source was modified.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2205 class DescribeLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#live_source_name ⇒ String
The name of the live source.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2205 class DescribeLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location associated with the live source.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2205 class DescribeLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the live source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2205 class DescribeLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |