Class: Aws::MediaTailor::Types::DescribeProgramResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::DescribeProgramResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_breaks ⇒ Array<Types::AdBreak>
The ad break configuration settings.
-
#arn ⇒ String
The ARN of the program.
-
#audience_media ⇒ Array<Types::AudienceMedia>
The list of AudienceMedia defined in program.
-
#channel_name ⇒ String
The name of the channel that the program belongs to.
-
#clip_range ⇒ Types::ClipRange
The clip range configuration settings.
-
#creation_time ⇒ Time
The timestamp of when the program was created.
-
#duration_millis ⇒ Integer
The duration of the live program in milliseconds.
-
#live_source_name ⇒ String
The name of the LiveSource for this Program.
-
#program_name ⇒ String
The name of the program.
-
#scheduled_start_time ⇒ Time
The date and time that the program is scheduled to start in ISO 8601 format and Coordinated Universal Time (UTC).
-
#source_location_name ⇒ String
The source location name.
-
#tags ⇒ Hash<String,String>
The tags assigned to the program.
-
#vod_source_name ⇒ String
The name that's used to refer to a VOD source.
Instance Attribute Details
#ad_breaks ⇒ Array<Types::AdBreak>
The ad break configuration settings.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the program.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#audience_media ⇒ Array<Types::AudienceMedia>
The list of AudienceMedia defined in program.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel that the program belongs to.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#clip_range ⇒ Types::ClipRange
The clip range configuration settings.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp of when the program was created.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#duration_millis ⇒ Integer
The duration of the live program in milliseconds.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#live_source_name ⇒ String
The name of the LiveSource for this Program.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#program_name ⇒ String
The name of the program.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#scheduled_start_time ⇒ Time
The date and time that the program is scheduled to start in ISO 8601 format and Coordinated Universal Time (UTC). For example, the value 2021-03-27T17:48:16.751Z represents March 27, 2021 at 17:48:16.751 UTC.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The source location name.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the program. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#vod_source_name ⇒ String
The name that's used to refer to a VOD source.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2298 class DescribeProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |