Class: Aws::MediaTailor::Types::DescribeSourceLocationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::DescribeSourceLocationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_configuration ⇒ Types::AccessConfiguration
The access configuration for the source location.
-
#arn ⇒ String
The ARN of the source location.
-
#creation_time ⇒ Time
The timestamp that indicates when the source location was created.
-
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The default segment delivery configuration settings.
-
#http_configuration ⇒ Types::HttpConfiguration
The HTTP package configuration settings for the source location.
-
#last_modified_time ⇒ Time
The timestamp that indicates when the source location was last modified.
-
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
A list of the segment delivery configurations associated with this resource.
-
#source_location_name ⇒ String
The name of the source location.
-
#tags ⇒ Hash<String,String>
The tags assigned to the source location.
Instance Attribute Details
#access_configuration ⇒ Types::AccessConfiguration
The access configuration for the source location.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2375 class DescribeSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the source location.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2375 class DescribeSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp that indicates when the source location was created.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2375 class DescribeSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The default segment delivery configuration settings.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2375 class DescribeSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#http_configuration ⇒ Types::HttpConfiguration
The HTTP package configuration settings for the source location.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2375 class DescribeSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp that indicates when the source location was last modified.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2375 class DescribeSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
A list of the segment delivery configurations associated with this resource.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2375 class DescribeSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2375 class DescribeSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the source location. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2375 class DescribeSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |