Class: Aws::MediaTailor::Types::DescribeVodSourceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ad_break_opportunitiesArray<Types::AdBreakOpportunity>

The ad break opportunities within the VOD source.

Returns:



2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447

class DescribeVodSourceResponse < Struct.new(
  :ad_break_opportunities,
  :arn,
  :creation_time,
  :http_package_configurations,
  :last_modified_time,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the VOD source.

Returns:

  • (String)


2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447

class DescribeVodSourceResponse < Struct.new(
  :ad_break_opportunities,
  :arn,
  :creation_time,
  :http_package_configurations,
  :last_modified_time,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The timestamp that indicates when the VOD source was created.

Returns:

  • (Time)


2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447

class DescribeVodSourceResponse < Struct.new(
  :ad_break_opportunities,
  :arn,
  :creation_time,
  :http_package_configurations,
  :last_modified_time,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#http_package_configurationsArray<Types::HttpPackageConfiguration>

The HTTP package configurations.



2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447

class DescribeVodSourceResponse < Struct.new(
  :ad_break_opportunities,
  :arn,
  :creation_time,
  :http_package_configurations,
  :last_modified_time,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The last modified time of the VOD source.

Returns:

  • (Time)


2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447

class DescribeVodSourceResponse < Struct.new(
  :ad_break_opportunities,
  :arn,
  :creation_time,
  :http_package_configurations,
  :last_modified_time,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#source_location_nameString

The name of the source location associated with the VOD source.

Returns:

  • (String)


2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447

class DescribeVodSourceResponse < Struct.new(
  :ad_break_opportunities,
  :arn,
  :creation_time,
  :http_package_configurations,
  :last_modified_time,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags assigned to the VOD source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Returns:

  • (Hash<String,String>)


2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447

class DescribeVodSourceResponse < Struct.new(
  :ad_break_opportunities,
  :arn,
  :creation_time,
  :http_package_configurations,
  :last_modified_time,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end

#vod_source_nameString

The name of the VOD source.

Returns:

  • (String)


2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447

class DescribeVodSourceResponse < Struct.new(
  :ad_break_opportunities,
  :arn,
  :creation_time,
  :http_package_configurations,
  :last_modified_time,
  :source_location_name,
  :tags,
  :vod_source_name)
  SENSITIVE = []
  include Aws::Structure
end