Class: Aws::MediaTailor::Types::GetChannelScheduleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audienceString

The single audience for GetChannelScheduleRequest.

Returns:



2630
2631
2632
2633
2634
2635
2636
2637
2638
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630

class GetChannelScheduleRequest < Struct.new(
  :channel_name,
  :duration_minutes,
  :max_results,
  :next_token,
  :audience)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel associated with this Channel Schedule.

Returns:



2630
2631
2632
2633
2634
2635
2636
2637
2638
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630

class GetChannelScheduleRequest < Struct.new(
  :channel_name,
  :duration_minutes,
  :max_results,
  :next_token,
  :audience)
  SENSITIVE = []
  include Aws::Structure
end

#duration_minutesString

The duration in minutes of the channel schedule.

Returns:



2630
2631
2632
2633
2634
2635
2636
2637
2638
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630

class GetChannelScheduleRequest < Struct.new(
  :channel_name,
  :duration_minutes,
  :max_results,
  :next_token,
  :audience)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of channel schedules that you want MediaTailor to return in response to the current request. If there are more than MaxResults channel schedules, use the value of NextToken in the response to get the next page of results.

Returns:



2630
2631
2632
2633
2634
2635
2636
2637
2638
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630

class GetChannelScheduleRequest < Struct.new(
  :channel_name,
  :duration_minutes,
  :max_results,
  :next_token,
  :audience)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

(Optional) If the playback configuration has more than MaxResults channel schedules, use NextToken to get the second and subsequent pages of results.

For the first GetChannelScheduleRequest request, omit this value.

For the second and subsequent requests, get the value of NextToken from the previous response and specify that value for NextToken in the request.

If the previous response didn't include a NextToken element, there are no more channel schedules to get.

Returns:



2630
2631
2632
2633
2634
2635
2636
2637
2638
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630

class GetChannelScheduleRequest < Struct.new(
  :channel_name,
  :duration_minutes,
  :max_results,
  :next_token,
  :audience)
  SENSITIVE = []
  include Aws::Structure
end