Class: Aws::MediaTailor::Types::GetFunctionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

-- Define Mixin --

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the function.

Returns:

  • (String)


2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#aws_service_request_configurationTypes::AwsServiceRequestConfiguration

The configuration for an AWS_SERVICE_REQUEST function. Specifies the target service, target Region, and request parameters.



2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#concurrent_executor_configurationTypes::ConcurrentExecutorConfiguration

The configuration for a CONCURRENT_EXECUTOR function.



2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#custom_output_configurationTypes::CustomOutputConfiguration

The configuration for a CUSTOM_OUTPUT function.



2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the function.

Returns:

  • (String)


2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#function_idString

The identifier of the function.

Returns:

  • (String)


2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#function_typeString

The type of the function.

Returns:

  • (String)


2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#http_request_configurationTypes::HttpRequestConfiguration

The configuration for an HTTP_REQUEST function.



2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#sequential_executor_configurationTypes::SequentialExecutorConfiguration

The configuration for a SEQUENTIAL_EXECUTOR function.



2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags assigned to the function. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Returns:

  • (Hash<String,String>)


2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#vast_request_configurationTypes::VastRequestConfiguration

The configuration for a VAST_REQUEST function.



2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729

class GetFunctionResponse < Struct.new(
  :function_id,
  :function_type,
  :description,
  :http_request_configuration,
  :aws_service_request_configuration,
  :custom_output_configuration,
  :concurrent_executor_configuration,
  :sequential_executor_configuration,
  :vast_request_configuration,
  :tags,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end