Class: Aws::MediaTailor::Types::GetPrefetchScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::GetPrefetchScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the prefetch schedule.
-
#playback_configuration_name ⇒ String
Returns information about the prefetch schedule for a specific playback configuration.
Instance Attribute Details
#name ⇒ String
The name of the prefetch schedule. The name must be unique among all prefetch schedules that are associated with the specified playback configuration.
3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3006 class GetPrefetchScheduleRequest < Struct.new( :name, :playback_configuration_name) SENSITIVE = [] include Aws::Structure end |
#playback_configuration_name ⇒ String
Returns information about the prefetch schedule for a specific
playback configuration. If you call GetPrefetchSchedule on an
expired prefetch schedule, MediaTailor returns an HTTP 404 status
code.
3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3006 class GetPrefetchScheduleRequest < Struct.new( :name, :playback_configuration_name) SENSITIVE = [] include Aws::Structure end |