Class: Aws::MediaTailor::Types::GetPrefetchScheduleResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the prefetch schedule.

Returns:

  • (String)


3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-mediatailor/types.rb', line 3073

class GetPrefetchScheduleResponse < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#consumptionTypes::PrefetchConsumption

The configuration settings for how and when MediaTailor consumes prefetched ads from the ad decision server for single prefetch schedules. Each consumption configuration contains an end time and an optional start time that define the consumption window. Prefetch schedules automatically expire no earlier than seven days after the end time.



3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-mediatailor/types.rb', line 3073

class GetPrefetchScheduleResponse < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the prefetch schedule. The name must be unique among all prefetch schedules that are associated with the specified playback configuration.

Returns:

  • (String)


3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-mediatailor/types.rb', line 3073

class GetPrefetchScheduleResponse < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#playback_configuration_nameString

The name of the playback configuration to create the prefetch schedule for.

Returns:

  • (String)


3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-mediatailor/types.rb', line 3073

class GetPrefetchScheduleResponse < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recurring_prefetch_configurationTypes::RecurringPrefetchConfiguration

The configuration that defines how and when MediaTailor performs ad prefetching in a live event.



3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-mediatailor/types.rb', line 3073

class GetPrefetchScheduleResponse < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#retrievalTypes::PrefetchRetrieval

A complex type that contains settings for prefetch retrieval from the ad decision server (ADS).



3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-mediatailor/types.rb', line 3073

class GetPrefetchScheduleResponse < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_typeString

The frequency that MediaTailor creates prefetch schedules. SINGLE indicates that this schedule applies to one ad break. RECURRING indicates that MediaTailor automatically creates a schedule for each ad avail in a live event.

Returns:

  • (String)


3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-mediatailor/types.rb', line 3073

class GetPrefetchScheduleResponse < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

An optional stream identifier that you can specify in order to prefetch for multiple streams that use the same playback configuration.

Returns:

  • (String)


3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-mediatailor/types.rb', line 3073

class GetPrefetchScheduleResponse < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags assigned to the prefetch schedule. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Returns:

  • (Hash<String,String>)


3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-mediatailor/types.rb', line 3073

class GetPrefetchScheduleResponse < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end