Class: Aws::MediaTailor::Types::HttpRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::HttpRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
HTTP request configuration parameters that define how MediaTailor communicates with the ad decision server.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#body ⇒ String
The request body content to send with HTTP requests to the ad decision server.
-
#compress_request ⇒ String
The compression method to apply to requests sent to the ad decision server.
-
#headers ⇒ Hash<String,String>
Custom HTTP headers to include in requests to the ad decision server.
-
#method ⇒ String
The HTTP method to use when making requests to the ad decision server.
Instance Attribute Details
#body ⇒ String
The request body content to send with HTTP requests to the ad
decision server. This value is only eligible for POST requests.
3204 3205 3206 3207 3208 3209 3210 3211 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3204 class HttpRequest < Struct.new( :method, :body, :headers, :compress_request) SENSITIVE = [] include Aws::Structure end |
#compress_request ⇒ String
The compression method to apply to requests sent to the ad decision
server. Supported values are NONE and GZIP. This value is only
eligible for POST requests.
3204 3205 3206 3207 3208 3209 3210 3211 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3204 class HttpRequest < Struct.new( :method, :body, :headers, :compress_request) SENSITIVE = [] include Aws::Structure end |
#headers ⇒ Hash<String,String>
Custom HTTP headers to include in requests to the ad decision
server. Specify headers as key-value pairs. This value is only
eligible for POST requests.
3204 3205 3206 3207 3208 3209 3210 3211 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3204 class HttpRequest < Struct.new( :method, :body, :headers, :compress_request) SENSITIVE = [] include Aws::Structure end |
#method ⇒ String
The HTTP method to use when making requests to the ad decision
server. Supported values are GET and POST.
3204 3205 3206 3207 3208 3209 3210 3211 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3204 class HttpRequest < Struct.new( :method, :body, :headers, :compress_request) SENSITIVE = [] include Aws::Structure end |