Class: Aws::MediaTailor::Types::KeyValuePair

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

For SCTE35_ENHANCED output, defines a key and corresponding value. MediaTailor generates these pairs within the EXT-X-ASSETtag.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyString

For SCTE35_ENHANCED output, defines a key. MediaTailor takes this key, and its associated value, and generates the key/value pair within the EXT-X-ASSETtag. If you specify a key, you must also specify a corresponding value.



3303
3304
3305
3306
3307
3308
# File 'lib/aws-sdk-mediatailor/types.rb', line 3303

class KeyValuePair < Struct.new(
  :key,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

For SCTE35_ENHANCED output, defines a value. MediaTailor; takes this value, and its associated key, and generates the key/value pair within the EXT-X-ASSETtag. If you specify a value, you must also specify a corresponding key.



3303
3304
3305
3306
3307
3308
# File 'lib/aws-sdk-mediatailor/types.rb', line 3303

class KeyValuePair < Struct.new(
  :key,
  :value)
  SENSITIVE = []
  include Aws::Structure
end