Class: Aws::MediaTailor::Types::LiveSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::LiveSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Live source configuration parameters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN for the live source.
-
#creation_time ⇒ Time
The timestamp that indicates when the live source was created.
-
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
The HTTP package configurations for the live source.
-
#last_modified_time ⇒ Time
The timestamp that indicates when the live source was last modified.
-
#live_source_name ⇒ String
The name that's used to refer to a live source.
-
#source_location_name ⇒ String
The name of the source location.
-
#tags ⇒ Hash<String,String>
The tags assigned to the live source.
Instance Attribute Details
#arn ⇒ String
The ARN for the live source.
3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3902 class LiveSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp that indicates when the live source was created.
3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3902 class LiveSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
The HTTP package configurations for the live source.
3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3902 class LiveSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp that indicates when the live source was last modified.
3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3902 class LiveSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#live_source_name ⇒ String
The name that's used to refer to a live source.
3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3902 class LiveSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location.
3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3902 class LiveSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the live source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3902 class LiveSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |