Class: Aws::MediaTailor::Types::ManifestServiceInteractionLog

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Settings for customizing what events are included in logs for interactions with the origin server.

For more information about manifest service logs, including descriptions of the event types, see MediaTailor manifest logs description and event types in Elemental MediaTailor User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#exclude_event_typesArray<String>

Indicates that MediaTailor won't emit the selected events in the logs for playback sessions that are initialized with this configuration.



4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-mediatailor/types.rb', line 4026

class ManifestServiceInteractionLog < Struct.new(
  :publish_opt_in_event_types,
  :exclude_event_types)
  SENSITIVE = []
  include Aws::Structure
end

#publish_opt_in_event_typesArray<String>

Indicates that MediaTailor will emit the selected events in the logs for playback sessions that are initialized with this configuration. These events are not emitted by default and must be explicitly opted in.



4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-mediatailor/types.rb', line 4026

class ManifestServiceInteractionLog < Struct.new(
  :publish_opt_in_event_types,
  :exclude_event_types)
  SENSITIVE = []
  include Aws::Structure
end