Class: Aws::MediaTailor::Types::PrefetchRetrieval

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

A complex type that contains settings governing when MediaTailor prefetches ads, and which dynamic variables that MediaTailor includes in the request to the ad decision server.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dynamic_variablesHash<String,String>

The dynamic variables to use for substitution during prefetch requests to the ad decision server (ADS).

You initially configure dynamic variables for the ADS URL when you set up your playback configuration. When you specify DynamicVariables for prefetch retrieval, MediaTailor includes the dynamic variables in the request to the ADS.

Returns:

  • (Hash<String,String>)


4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
# File 'lib/aws-sdk-mediatailor/types.rb', line 4397

class PrefetchRetrieval < Struct.new(
  :dynamic_variables,
  :end_time,
  :start_time,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time when prefetch retrieval ends for the ad break. Prefetching will be attempted for manifest requests that occur at or before this time.

Returns:

  • (Time)


4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
# File 'lib/aws-sdk-mediatailor/types.rb', line 4397

class PrefetchRetrieval < Struct.new(
  :dynamic_variables,
  :end_time,
  :start_time,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The time when prefetch retrievals can start for this break. Ad prefetching will be attempted for manifest requests that occur at or after this time. Defaults to the current time. If not specified, the prefetch retrieval starts as soon as possible.

Returns:

  • (Time)


4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
# File 'lib/aws-sdk-mediatailor/types.rb', line 4397

class PrefetchRetrieval < Struct.new(
  :dynamic_variables,
  :end_time,
  :start_time,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_shaping_retrieval_windowTypes::TrafficShapingRetrievalWindow

The configuration that tells Elemental MediaTailor how many seconds to spread out requests to the ad decision server (ADS). Instead of sending ADS requests for all sessions at the same time, MediaTailor spreads the requests across the amount of time specified in the retrieval window.



4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
# File 'lib/aws-sdk-mediatailor/types.rb', line 4397

class PrefetchRetrieval < Struct.new(
  :dynamic_variables,
  :end_time,
  :start_time,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_shaping_tps_configurationTypes::TrafficShapingTpsConfiguration

The configuration for TPS-based traffic shaping. This approach limits requests to the ad decision server (ADS) based on transactions per second and concurrent users.



4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
# File 'lib/aws-sdk-mediatailor/types.rb', line 4397

class PrefetchRetrieval < Struct.new(
  :dynamic_variables,
  :end_time,
  :start_time,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_shaping_typeString

Indicates the type of traffic shaping used to limit the number of requests to the ADS at one time.

Returns:

  • (String)


4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
# File 'lib/aws-sdk-mediatailor/types.rb', line 4397

class PrefetchRetrieval < Struct.new(
  :dynamic_variables,
  :end_time,
  :start_time,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end