Class: Aws::MediaTailor::Types::PrefetchSchedule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

A prefetch schedule allows you to tell MediaTailor to fetch and prepare certain ads before an ad break happens. For more information about ad prefetching, see Using ad prefetching in the MediaTailor User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the prefetch schedule.

Returns:



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484

class PrefetchSchedule < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#consumptionTypes::PrefetchConsumption

Consumption settings determine how, and when, MediaTailor places the prefetched ads into ad breaks for single prefetch schedules. Ad consumption occurs within a span of time that you define, called a consumption window. You can designate which ad breaks that MediaTailor fills with prefetch ads by setting avail matching criteria.

Returns:



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484

class PrefetchSchedule < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the prefetch schedule. The name must be unique among all prefetch schedules that are associated with the specified playback configuration.

Returns:



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484

class PrefetchSchedule < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#playback_configuration_nameString

The name of the playback configuration to create the prefetch schedule for.

Returns:



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484

class PrefetchSchedule < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recurring_prefetch_configurationTypes::RecurringPrefetchConfiguration

The settings that determine how and when MediaTailor prefetches ads and inserts them into ad breaks.

Returns:



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484

class PrefetchSchedule < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#retrievalTypes::PrefetchRetrieval

A complex type that contains settings for prefetch retrieval from the ad decision server (ADS).

Returns:



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484

class PrefetchSchedule < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_typeString

The frequency that MediaTailor creates prefetch schedules. SINGLE indicates that this schedule applies to one ad break. RECURRING indicates that MediaTailor automatically creates a schedule for each ad avail in a live event.

For more information about the prefetch types and when you might use each, see Prefetching ads in Elemental MediaTailor.

Returns:



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484

class PrefetchSchedule < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

An optional stream identifier that you can specify in order to prefetch for multiple streams that use the same playback configuration.

Returns:



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484

class PrefetchSchedule < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags assigned to the prefetch schedule. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Returns:



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484

class PrefetchSchedule < Struct.new(
  :arn,
  :consumption,
  :name,
  :playback_configuration_name,
  :retrieval,
  :schedule_type,
  :recurring_prefetch_configuration,
  :stream_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end