Class: Aws::MediaTailor::Types::PutChannelPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::PutChannelPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_name ⇒ String
The channel name associated with this Channel Policy.
-
#policy ⇒ String
Adds an IAM role that determines the permissions of your channel.
Instance Attribute Details
#channel_name ⇒ String
The channel name associated with this Channel Policy.
4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4508 class PutChannelPolicyRequest < Struct.new( :channel_name, :policy) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
Adds an IAM role that determines the permissions of your channel.
4508 4509 4510 4511 4512 4513 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4508 class PutChannelPolicyRequest < Struct.new( :channel_name, :policy) SENSITIVE = [] include Aws::Structure end |