Class: Aws::MediaTailor::Types::RecurringRetrieval

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

With recurring prefetch, MediaTailor automatically prefetches ads for every avail that occurs during the retrieval window. The following configurations describe the MediaTailor behavior when prefetching ads for a live event.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delay_after_avail_end_secondsInteger

The number of seconds that MediaTailor waits after an ad avail before prefetching ads for the next avail. If not set, the default is 0 (no delay).

Returns:

  • (Integer)


5219
5220
5221
5222
5223
5224
5225
5226
5227
# File 'lib/aws-sdk-mediatailor/types.rb', line 5219

class RecurringRetrieval < Struct.new(
  :dynamic_variables,
  :delay_after_avail_end_seconds,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dynamic_variablesHash<String,String>

The dynamic variables to use for substitution during prefetch requests to the ADS.

Returns:

  • (Hash<String,String>)


5219
5220
5221
5222
5223
5224
5225
5226
5227
# File 'lib/aws-sdk-mediatailor/types.rb', line 5219

class RecurringRetrieval < Struct.new(
  :dynamic_variables,
  :delay_after_avail_end_seconds,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_shaping_retrieval_windowTypes::TrafficShapingRetrievalWindow

The configuration that tells Elemental MediaTailor how many seconds to spread out requests to the ad decision server (ADS). Instead of sending ADS requests for all sessions at the same time, MediaTailor spreads the requests across the amount of time specified in the retrieval window.



5219
5220
5221
5222
5223
5224
5225
5226
5227
# File 'lib/aws-sdk-mediatailor/types.rb', line 5219

class RecurringRetrieval < Struct.new(
  :dynamic_variables,
  :delay_after_avail_end_seconds,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_shaping_tps_configurationTypes::TrafficShapingTpsConfiguration

The configuration for TPS-based traffic shaping. This approach limits requests to the ad decision server (ADS) based on transactions per second and concurrent users.



5219
5220
5221
5222
5223
5224
5225
5226
5227
# File 'lib/aws-sdk-mediatailor/types.rb', line 5219

class RecurringRetrieval < Struct.new(
  :dynamic_variables,
  :delay_after_avail_end_seconds,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_shaping_typeString

Indicates the type of traffic shaping used to limit the number of requests to the ADS at one time.

Returns:

  • (String)


5219
5220
5221
5222
5223
5224
5225
5226
5227
# File 'lib/aws-sdk-mediatailor/types.rb', line 5219

class RecurringRetrieval < Struct.new(
  :dynamic_variables,
  :delay_after_avail_end_seconds,
  :traffic_shaping_type,
  :traffic_shaping_retrieval_window,
  :traffic_shaping_tps_configuration)
  SENSITIVE = []
  include Aws::Structure
end