Class: Aws::MediaTailor::Types::ScheduleEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

The properties for a schedule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_duration_secondsInteger

The approximate duration of this program, in seconds.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#approximate_start_timeTime

The approximate time that the program will start playing.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the program.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#audiencesArray<String>

The list of audiences defined in ScheduleEntry.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel that uses this schedule.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#live_source_nameString

The name of the live source used for the program.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#program_nameString

The name of the program.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_ad_breaksArray<Types::ScheduleAdBreak>

The schedule's ad break properties.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_entry_typeString

The type of schedule entry.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#source_location_nameString

The name of the source location.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#vod_source_nameString

The name of the VOD source.

Returns:



5400
5401
5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
# File 'lib/aws-sdk-mediatailor/types.rb', line 5400

class ScheduleEntry < Struct.new(
  :approximate_duration_seconds,
  :approximate_start_time,
  :arn,
  :channel_name,
  :live_source_name,
  :program_name,
  :schedule_ad_breaks,
  :schedule_entry_type,
  :source_location_name,
  :vod_source_name,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end