Class: Aws::MediaTailor::Types::SecretsManagerAccessTokenConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::SecretsManagerAccessTokenConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
AWS Secrets Manager access token configuration parameters. For information about Secrets Manager access token authentication, see Working with AWS Secrets Manager access token authentication.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#header_name ⇒ String
The name of the HTTP header used to supply the access token in requests to the source location.
-
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the AWS Secrets Manager secret that contains the access token.
-
#secret_string_key ⇒ String
The AWS Secrets Manager [SecretString][1] key associated with the access token.
Instance Attribute Details
#header_name ⇒ String
The name of the HTTP header used to supply the access token in requests to the source location.
5446 5447 5448 5449 5450 5451 5452 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5446 class SecretsManagerAccessTokenConfiguration < Struct.new( :header_name, :secret_arn, :secret_string_key) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the AWS Secrets Manager secret that contains the access token.
5446 5447 5448 5449 5450 5451 5452 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5446 class SecretsManagerAccessTokenConfiguration < Struct.new( :header_name, :secret_arn, :secret_string_key) SENSITIVE = [] include Aws::Structure end |
#secret_string_key ⇒ String
The AWS Secrets Manager SecretString key associated with the access token. MediaTailor uses the key to look up SecretString key and value pair containing the access token.
5446 5447 5448 5449 5450 5451 5452 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5446 class SecretsManagerAccessTokenConfiguration < Struct.new( :header_name, :secret_arn, :secret_string_key) SENSITIVE = [] include Aws::Structure end |