Class: Aws::MediaTailor::Types::SourceLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

A source location is a container for sources. For more information about source locations, see Working with source locations in the MediaTailor User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_configurationTypes::AccessConfiguration

The access configuration for the source location.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686

class SourceLocation < Struct.new(
  :access_configuration,
  :arn,
  :creation_time,
  :default_segment_delivery_configuration,
  :http_configuration,
  :last_modified_time,
  :segment_delivery_configurations,
  :source_location_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the SourceLocation.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686

class SourceLocation < Struct.new(
  :access_configuration,
  :arn,
  :creation_time,
  :default_segment_delivery_configuration,
  :http_configuration,
  :last_modified_time,
  :segment_delivery_configurations,
  :source_location_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The timestamp that indicates when the source location was created.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686

class SourceLocation < Struct.new(
  :access_configuration,
  :arn,
  :creation_time,
  :default_segment_delivery_configuration,
  :http_configuration,
  :last_modified_time,
  :segment_delivery_configurations,
  :source_location_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_segment_delivery_configurationTypes::DefaultSegmentDeliveryConfiguration

The default segment delivery configuration.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686

class SourceLocation < Struct.new(
  :access_configuration,
  :arn,
  :creation_time,
  :default_segment_delivery_configuration,
  :http_configuration,
  :last_modified_time,
  :segment_delivery_configurations,
  :source_location_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#http_configurationTypes::HttpConfiguration

The HTTP configuration for the source location.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686

class SourceLocation < Struct.new(
  :access_configuration,
  :arn,
  :creation_time,
  :default_segment_delivery_configuration,
  :http_configuration,
  :last_modified_time,
  :segment_delivery_configurations,
  :source_location_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp that indicates when the source location was last modified.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686

class SourceLocation < Struct.new(
  :access_configuration,
  :arn,
  :creation_time,
  :default_segment_delivery_configuration,
  :http_configuration,
  :last_modified_time,
  :segment_delivery_configurations,
  :source_location_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#segment_delivery_configurationsArray<Types::SegmentDeliveryConfiguration>

The segment delivery configurations for the source location.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686

class SourceLocation < Struct.new(
  :access_configuration,
  :arn,
  :creation_time,
  :default_segment_delivery_configuration,
  :http_configuration,
  :last_modified_time,
  :segment_delivery_configurations,
  :source_location_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#source_location_nameString

The name of the source location.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686

class SourceLocation < Struct.new(
  :access_configuration,
  :arn,
  :creation_time,
  :default_segment_delivery_configuration,
  :http_configuration,
  :last_modified_time,
  :segment_delivery_configurations,
  :source_location_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags assigned to the source location. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686

class SourceLocation < Struct.new(
  :access_configuration,
  :arn,
  :creation_time,
  :default_segment_delivery_configuration,
  :http_configuration,
  :last_modified_time,
  :segment_delivery_configurations,
  :source_location_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end