Class: Aws::MediaTailor::Types::TrafficShapingTpsConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

The configuration for TPS-based traffic shaping. This approach limits requests to the ad decision server (ADS) based on transactions per second and concurrent users.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#peak_concurrent_usersInteger

The expected peak number of concurrent viewers for your content. MediaTailor uses this value along with peak TPS to determine how to distribute prefetch requests across the available capacity without exceeding your ADS limits.

Returns:



5873
5874
5875
5876
5877
5878
# File 'lib/aws-sdk-mediatailor/types.rb', line 5873

class TrafficShapingTpsConfiguration < Struct.new(
  :peak_tps,
  :peak_concurrent_users)
  SENSITIVE = []
  include Aws::Structure
end

#peak_tpsInteger

The maximum number of transactions per second (TPS) that your ad decision server (ADS) can handle. MediaTailor uses this value along with concurrent users and headroom multiplier to calculate optimal traffic distribution and prevent ADS overload.

Returns:



5873
5874
5875
5876
5877
5878
# File 'lib/aws-sdk-mediatailor/types.rb', line 5873

class TrafficShapingTpsConfiguration < Struct.new(
  :peak_tps,
  :peak_concurrent_users)
  SENSITIVE = []
  include Aws::Structure
end