Class: Aws::MediaTailor::Types::UpdateChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audiencesArray<String>

The list of audiences defined in channel.

Returns:

  • (Array<String>)


5977
5978
5979
5980
5981
5982
5983
5984
5985
# File 'lib/aws-sdk-mediatailor/types.rb', line 5977

class UpdateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel.

Returns:

  • (String)


5977
5978
5979
5980
5981
5982
5983
5984
5985
# File 'lib/aws-sdk-mediatailor/types.rb', line 5977

class UpdateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#filler_slateTypes::SlateSource

The slate used to fill gaps between programs in the schedule. You must configure filler slate if your channel uses the LINEAR PlaybackMode. MediaTailor doesn't support filler slate for channels using the LOOP PlaybackMode.

Returns:



5977
5978
5979
5980
5981
5982
5983
5984
5985
# File 'lib/aws-sdk-mediatailor/types.rb', line 5977

class UpdateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::RequestOutputItem>

The channel's output properties.

Returns:



5977
5978
5979
5980
5981
5982
5983
5984
5985
# File 'lib/aws-sdk-mediatailor/types.rb', line 5977

class UpdateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#time_shift_configurationTypes::TimeShiftConfiguration

The time-shifted viewing configuration you want to associate to the channel.



5977
5978
5979
5980
5981
5982
5983
5984
5985
# File 'lib/aws-sdk-mediatailor/types.rb', line 5977

class UpdateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end