Class: Aws::MediaTailor::Types::UpdateChannelResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) associated with the channel.

Returns:

  • (String)


6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#audiencesArray<String>

The list of audiences defined in channel.

Returns:

  • (Array<String>)


6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel.

Returns:

  • (String)


6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#channel_stateString

Returns the state whether the channel is running or not.

Returns:

  • (String)


6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The timestamp of when the channel was created.

Returns:

  • (Time)


6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#filler_slateTypes::SlateSource

The slate used to fill gaps between programs in the schedule. You must configure filler slate if your channel uses the LINEAR PlaybackMode. MediaTailor doesn't support filler slate for channels using the LOOP PlaybackMode.

Returns:



6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The timestamp that indicates when the channel was last modified.

Returns:

  • (Time)


6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::ResponseOutputItem>

The channel's output properties.

Returns:



6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#playback_modeString

The type of playback mode for this channel.

LINEAR - Programs play back-to-back only once.

LOOP - Programs play back-to-back in an endless loop. When the last program in the schedule plays, playback loops back to the first program in the schedule.

Returns:

  • (String)


6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to assign to the channel. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Returns:

  • (Hash<String,String>)


6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

The tier associated with this Channel.

Returns:

  • (String)


6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#time_shift_configurationTypes::TimeShiftConfiguration

The time-shifted viewing configuration for the channel.



6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053

class UpdateChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_state,
  :creation_time,
  :filler_slate,
  :last_modified_time,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end