Class: Aws::MediaTailor::Types::UpdateLiveSourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::UpdateLiveSourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with this live source.
-
#creation_time ⇒ Time
The timestamp that indicates when the live source was created.
-
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configurations for the live source on this account.
-
#last_modified_time ⇒ Time
The timestamp that indicates when the live source was last modified.
-
#live_source_name ⇒ String
The name of the live source.
-
#source_location_name ⇒ String
The name of the source location associated with the live source.
-
#tags ⇒ Hash<String,String>
The tags to assign to the live source.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) associated with this live source.
6131 6132 6133 6134 6135 6136 6137 6138 6139 6140 6141 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6131 class UpdateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp that indicates when the live source was created.
6131 6132 6133 6134 6135 6136 6137 6138 6139 6140 6141 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6131 class UpdateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configurations for the live source on this account.
6131 6132 6133 6134 6135 6136 6137 6138 6139 6140 6141 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6131 class UpdateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp that indicates when the live source was last modified.
6131 6132 6133 6134 6135 6136 6137 6138 6139 6140 6141 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6131 class UpdateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#live_source_name ⇒ String
The name of the live source.
6131 6132 6133 6134 6135 6136 6137 6138 6139 6140 6141 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6131 class UpdateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location associated with the live source.
6131 6132 6133 6134 6135 6136 6137 6138 6139 6140 6141 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6131 class UpdateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the live source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
6131 6132 6133 6134 6135 6136 6137 6138 6139 6140 6141 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6131 class UpdateLiveSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :live_source_name, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |