Class: Aws::MediaTailor::Types::UpdateVodSourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::UpdateVodSourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the VOD source.
-
#creation_time ⇒ Time
The timestamp that indicates when the VOD source was created.
-
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configurations for the VOD source on this account.
-
#last_modified_time ⇒ Time
The timestamp that indicates when the VOD source was last modified.
-
#source_location_name ⇒ String
The name of the source location associated with the VOD source.
-
#tags ⇒ Hash<String,String>
The tags to assign to the VOD source.
-
#vod_source_name ⇒ String
The name of the VOD source.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the VOD source.
6455 6456 6457 6458 6459 6460 6461 6462 6463 6464 6465 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6455 class UpdateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp that indicates when the VOD source was created.
6455 6456 6457 6458 6459 6460 6461 6462 6463 6464 6465 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6455 class UpdateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
A list of HTTP package configurations for the VOD source on this account.
6455 6456 6457 6458 6459 6460 6461 6462 6463 6464 6465 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6455 class UpdateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp that indicates when the VOD source was last modified.
6455 6456 6457 6458 6459 6460 6461 6462 6463 6464 6465 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6455 class UpdateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location associated with the VOD source.
6455 6456 6457 6458 6459 6460 6461 6462 6463 6464 6465 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6455 class UpdateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the VOD source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
6455 6456 6457 6458 6459 6460 6461 6462 6463 6464 6465 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6455 class UpdateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#vod_source_name ⇒ String
The name of the VOD source.
6455 6456 6457 6458 6459 6460 6461 6462 6463 6464 6465 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6455 class UpdateVodSourceResponse < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |