Class: Aws::MediaTailor::Types::VodSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::VodSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
VOD source configuration parameters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN for the VOD source.
-
#creation_time ⇒ Time
The timestamp that indicates when the VOD source was created.
-
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
The HTTP package configurations for the VOD source.
-
#last_modified_time ⇒ Time
The timestamp that indicates when the VOD source was last modified.
-
#source_location_name ⇒ String
The name of the source location that the VOD source is associated with.
-
#tags ⇒ Hash<String,String>
The tags assigned to the VOD source.
-
#vod_source_name ⇒ String
The name of the VOD source.
Instance Attribute Details
#arn ⇒ String
The ARN for the VOD source.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6613 class VodSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp that indicates when the VOD source was created.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6613 class VodSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
The HTTP package configurations for the VOD source.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6613 class VodSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp that indicates when the VOD source was last modified.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6613 class VodSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location that the VOD source is associated with.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6613 class VodSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the VOD source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6613 class VodSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#vod_source_name ⇒ String
The name of the VOD source.
6613 6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6613 class VodSource < Struct.new( :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |