Class: Aws::MediaTailor::Types::AdsInteractionLog
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::AdsInteractionLog
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Settings for customizing what events are included in logs for interactions with the ad decision server (ADS).
For more information about ADS logs, inlcuding descriptions of the event types, see MediaTailor ADS logs description and event types in Elemental MediaTailor User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exclude_event_types ⇒ Array<String>
Indicates that MediaTailor won't emit the selected events in the logs for playback sessions that are initialized with this configuration.
-
#publish_opt_in_event_types ⇒ Array<String>
Indicates that MediaTailor will emit the selected events in the logs for playback sessions that are initialized with this configuration.
Instance Attribute Details
#exclude_event_types ⇒ Array<String>
Indicates that MediaTailor won't emit the selected events in the logs for playback sessions that are initialized with this configuration.
266 267 268 269 270 271 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 266 class AdsInteractionLog < Struct.new( :publish_opt_in_event_types, :exclude_event_types) SENSITIVE = [] include Aws::Structure end |
#publish_opt_in_event_types ⇒ Array<String>
Indicates that MediaTailor will emit the selected events in the logs for playback sessions that are initialized with this configuration. These events are not emitted by default and must be explicitly opted in. For descriptions of each event type, see MediaTailor ADS logs description and event types in Elemental MediaTailor User Guide.
266 267 268 269 270 271 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 266 class AdsInteractionLog < Struct.new( :publish_opt_in_event_types, :exclude_event_types) SENSITIVE = [] include Aws::Structure end |