Class: Aws::MediaTailor::Types::CreateChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediatailor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audiencesArray<String>

The list of audiences defined in channel.

Returns:

  • (Array<String>)


833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-mediatailor/types.rb', line 833

class CreateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel.

Returns:

  • (String)


833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-mediatailor/types.rb', line 833

class CreateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#filler_slateTypes::SlateSource

The slate used to fill gaps between programs in the schedule. You must configure filler slate if your channel uses the LINEAR PlaybackMode. MediaTailor doesn’t support filler slate for channels using the LOOP PlaybackMode.

Returns:



833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-mediatailor/types.rb', line 833

class CreateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::RequestOutputItem>

The channel’s output properties.

Returns:



833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-mediatailor/types.rb', line 833

class CreateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#playback_modeString

The type of playback mode to use for this channel.

LINEAR - The programs in the schedule play once back-to-back in the schedule.

LOOP - The programs in the schedule play back-to-back in an endless loop. When the last program in the schedule stops playing, playback loops back to the first program in the schedule.

Returns:

  • (String)


833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-mediatailor/types.rb', line 833

class CreateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to assign to the channel. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see [Tagging AWS Elemental MediaTailor Resources].

[1]: docs.aws.amazon.com/mediatailor/latest/ug/tagging.html

Returns:

  • (Hash<String,String>)


833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-mediatailor/types.rb', line 833

class CreateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#tierString

The tier of the channel.

Returns:

  • (String)


833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-mediatailor/types.rb', line 833

class CreateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end

#time_shift_configurationTypes::TimeShiftConfiguration

The time-shifted viewing configuration you want to associate to the channel.



833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-mediatailor/types.rb', line 833

class CreateChannelRequest < Struct.new(
  :channel_name,
  :filler_slate,
  :outputs,
  :playback_mode,
  :tags,
  :tier,
  :time_shift_configuration,
  :audiences)
  SENSITIVE = []
  include Aws::Structure
end