Class: Aws::MediaTailor::Types::CreateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::CreateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audiences ⇒ Array<String>
The list of audiences defined in channel.
-
#channel_name ⇒ String
The name of the channel.
-
#filler_slate ⇒ Types::SlateSource
The slate used to fill gaps between programs in the schedule.
-
#outputs ⇒ Array<Types::RequestOutputItem>
The channel's output properties.
-
#playback_mode ⇒ String
The type of playback mode to use for this channel.
-
#tags ⇒ Hash<String,String>
The tags to assign to the channel.
-
#tier ⇒ String
The tier of the channel.
-
#time_shift_configuration ⇒ Types::TimeShiftConfiguration
The time-shifted viewing configuration you want to associate to the channel.
Instance Attribute Details
#audiences ⇒ Array<String>
The list of audiences defined in channel.
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1066 class CreateChannelRequest < Struct.new( :channel_name, :filler_slate, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel.
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1066 class CreateChannelRequest < Struct.new( :channel_name, :filler_slate, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#filler_slate ⇒ Types::SlateSource
The slate used to fill gaps between programs in the schedule. You
must configure filler slate if your channel uses the LINEAR
PlaybackMode. MediaTailor doesn't support filler slate for
channels using the LOOP PlaybackMode.
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1066 class CreateChannelRequest < Struct.new( :channel_name, :filler_slate, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::RequestOutputItem>
The channel's output properties.
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1066 class CreateChannelRequest < Struct.new( :channel_name, :filler_slate, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#playback_mode ⇒ String
The type of playback mode to use for this channel.
LINEAR - The programs in the schedule play once back-to-back in
the schedule.
LOOP - The programs in the schedule play back-to-back in an
endless loop. When the last program in the schedule stops playing,
playback loops back to the first program in the schedule.
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1066 class CreateChannelRequest < Struct.new( :channel_name, :filler_slate, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the channel. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1066 class CreateChannelRequest < Struct.new( :channel_name, :filler_slate, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
The tier of the channel.
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1066 class CreateChannelRequest < Struct.new( :channel_name, :filler_slate, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#time_shift_configuration ⇒ Types::TimeShiftConfiguration
The time-shifted viewing configuration you want to associate to the channel.
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1066 class CreateChannelRequest < Struct.new( :channel_name, :filler_slate, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |