Class: Aws::MediaTailor::Types::CreateProgramResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::CreateProgramResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_breaks ⇒ Array<Types::AdBreak>
The ad break configuration settings.
-
#arn ⇒ String
The ARN to assign to the program.
-
#audience_media ⇒ Array<Types::AudienceMedia>
The list of AudienceMedia defined in program.
-
#channel_name ⇒ String
The name to assign to the channel for this program.
-
#clip_range ⇒ Types::ClipRange
The clip range configuration settings.
-
#creation_time ⇒ Time
The time the program was created.
-
#duration_millis ⇒ Integer
The duration of the live program in milliseconds.
-
#live_source_name ⇒ String
The name of the LiveSource for this Program.
-
#program_name ⇒ String
The name to assign to this program.
-
#scheduled_start_time ⇒ Time
The scheduled start time for this Program.
-
#source_location_name ⇒ String
The name to assign to the source location for this program.
-
#tags ⇒ Hash<String,String>
The tags assigned to the program.
-
#vod_source_name ⇒ String
The name that's used to refer to a VOD source.
Instance Attribute Details
#ad_breaks ⇒ Array<Types::AdBreak>
The ad break configuration settings.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN to assign to the program.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#audience_media ⇒ Array<Types::AudienceMedia>
The list of AudienceMedia defined in program.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name to assign to the channel for this program.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#clip_range ⇒ Types::ClipRange
The clip range configuration settings.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time the program was created.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#duration_millis ⇒ Integer
The duration of the live program in milliseconds.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#live_source_name ⇒ String
The name of the LiveSource for this Program.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#program_name ⇒ String
The name to assign to this program.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#scheduled_start_time ⇒ Time
The scheduled start time for this Program.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name to assign to the source location for this program.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the program. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |
#vod_source_name ⇒ String
The name that's used to refer to a VOD source.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1511 class CreateProgramResponse < Struct.new( :ad_breaks, :arn, :channel_name, :creation_time, :live_source_name, :program_name, :scheduled_start_time, :source_location_name, :vod_source_name, :clip_range, :duration_millis, :audience_media, :tags) SENSITIVE = [] include Aws::Structure end |