Class: Aws::MediaTailor::Types::CreateSourceLocationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::CreateSourceLocationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_configuration ⇒ Types::AccessConfiguration
Access configuration parameters.
-
#arn ⇒ String
The ARN to assign to the source location.
-
#creation_time ⇒ Time
The time the source location was created.
-
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The optional configuration for the server that serves segments.
-
#http_configuration ⇒ Types::HttpConfiguration
The source’s HTTP package configurations.
-
#last_modified_time ⇒ Time
The time the source location was last modified.
-
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
The segment delivery configurations for the source location.
-
#source_location_name ⇒ String
The name to assign to the source location.
-
#tags ⇒ Hash<String,String>
The tags to assign to the source location.
Instance Attribute Details
#access_configuration ⇒ Types::AccessConfiguration
Access configuration parameters. Configures the type of authentication used to access content from your source location.
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1346 class CreateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN to assign to the source location.
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1346 class CreateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time the source location was created.
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1346 class CreateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The optional configuration for the server that serves segments.
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1346 class CreateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#http_configuration ⇒ Types::HttpConfiguration
The source’s HTTP package configurations.
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1346 class CreateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The time the source location was last modified.
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1346 class CreateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
The segment delivery configurations for the source location. For information about MediaTailor configurations, see [Working with configurations in AWS Elemental MediaTailor][1].
[1]: docs.aws.amazon.com/mediatailor/latest/ug/configurations.html
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1346 class CreateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name to assign to the source location.
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1346 class CreateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the source location. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see [Tagging AWS Elemental MediaTailor Resources][1].
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 1346 class CreateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |