Class: Aws::MediaTailor::Types::DescribeVodSourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::DescribeVodSourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_break_opportunities ⇒ Array<Types::AdBreakOpportunity>
The ad break opportunities within the VOD source.
-
#arn ⇒ String
The ARN of the VOD source.
-
#creation_time ⇒ Time
The timestamp that indicates when the VOD source was created.
-
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
The HTTP package configurations.
-
#last_modified_time ⇒ Time
The last modified time of the VOD source.
-
#source_location_name ⇒ String
The name of the source location associated with the VOD source.
-
#tags ⇒ Hash<String,String>
The tags assigned to the VOD source.
-
#vod_source_name ⇒ String
The name of the VOD source.
Instance Attribute Details
#ad_break_opportunities ⇒ Array<Types::AdBreakOpportunity>
The ad break opportunities within the VOD source.
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447 class DescribeVodSourceResponse < Struct.new( :ad_break_opportunities, :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the VOD source.
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447 class DescribeVodSourceResponse < Struct.new( :ad_break_opportunities, :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp that indicates when the VOD source was created.
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447 class DescribeVodSourceResponse < Struct.new( :ad_break_opportunities, :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#http_package_configurations ⇒ Array<Types::HttpPackageConfiguration>
The HTTP package configurations.
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447 class DescribeVodSourceResponse < Struct.new( :ad_break_opportunities, :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The last modified time of the VOD source.
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447 class DescribeVodSourceResponse < Struct.new( :ad_break_opportunities, :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location associated with the VOD source.
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447 class DescribeVodSourceResponse < Struct.new( :ad_break_opportunities, :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the VOD source. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447 class DescribeVodSourceResponse < Struct.new( :ad_break_opportunities, :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |
#vod_source_name ⇒ String
The name of the VOD source.
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2447 class DescribeVodSourceResponse < Struct.new( :ad_break_opportunities, :arn, :creation_time, :http_package_configurations, :last_modified_time, :source_location_name, :tags, :vod_source_name) SENSITIVE = [] include Aws::Structure end |