Class: Aws::MediaTailor::Types::FunctionRef
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::FunctionRef
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
A reference to a child function within a SEQUENTIAL_EXECUTOR
function.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
An optional alternate name for the function within the executor.
-
#function_id ⇒ String
The identifier of the child function to execute in this step.
-
#run_condition ⇒ String
An optional expression that evaluates to a boolean.
Instance Attribute Details
#alias ⇒ String
An optional alternate name for the function within the executor. If omitted, MediaTailor uses the function identifier.
2561 2562 2563 2564 2565 2566 2567 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2561 class FunctionRef < Struct.new( :run_condition, :function_id, :alias) SENSITIVE = [] include Aws::Structure end |
#function_id ⇒ String
The identifier of the child function to execute in this step.
2561 2562 2563 2564 2565 2566 2567 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2561 class FunctionRef < Struct.new( :run_condition, :function_id, :alias) SENSITIVE = [] include Aws::Structure end |
#run_condition ⇒ String
An optional expression that evaluates to a boolean. MediaTailor
evaluates this expression immediately before running the step, using
the accumulated state at that point in the sequence. If the
expression evaluates to false, MediaTailor skips the step and
moves to the next one. If omitted, the step always runs.
2561 2562 2563 2564 2565 2566 2567 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2561 class FunctionRef < Struct.new( :run_condition, :function_id, :alias) SENSITIVE = [] include Aws::Structure end |