Class: Aws::MediaTailor::Types::GetChannelScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::GetChannelScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audience ⇒ String
The single audience for GetChannelScheduleRequest.
-
#channel_name ⇒ String
The name of the channel associated with this Channel Schedule.
-
#duration_minutes ⇒ String
The duration in minutes of the channel schedule.
-
#max_results ⇒ Integer
The maximum number of channel schedules that you want MediaTailor to return in response to the current request.
-
#next_token ⇒ String
(Optional) If the playback configuration has more than
MaxResultschannel schedules, useNextTokento get the second and subsequent pages of results.
Instance Attribute Details
#audience ⇒ String
The single audience for GetChannelScheduleRequest.
2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630 class GetChannelScheduleRequest < Struct.new( :channel_name, :duration_minutes, :max_results, :next_token, :audience) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel associated with this Channel Schedule.
2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630 class GetChannelScheduleRequest < Struct.new( :channel_name, :duration_minutes, :max_results, :next_token, :audience) SENSITIVE = [] include Aws::Structure end |
#duration_minutes ⇒ String
The duration in minutes of the channel schedule.
2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630 class GetChannelScheduleRequest < Struct.new( :channel_name, :duration_minutes, :max_results, :next_token, :audience) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of channel schedules that you want MediaTailor to
return in response to the current request. If there are more than
MaxResults channel schedules, use the value of NextToken in the
response to get the next page of results.
2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630 class GetChannelScheduleRequest < Struct.new( :channel_name, :duration_minutes, :max_results, :next_token, :audience) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
(Optional) If the playback configuration has more than MaxResults
channel schedules, use NextToken to get the second and subsequent
pages of results.
For the first GetChannelScheduleRequest request, omit this value.
For the second and subsequent requests, get the value of NextToken
from the previous response and specify that value for NextToken in
the request.
If the previous response didn't include a NextToken element,
there are no more channel schedules to get.
2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2630 class GetChannelScheduleRequest < Struct.new( :channel_name, :duration_minutes, :max_results, :next_token, :audience) SENSITIVE = [] include Aws::Structure end |