Class: Aws::MediaTailor::Types::GetFunctionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::GetFunctionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
-- Define Mixin --
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the function.
-
#aws_service_request_configuration ⇒ Types::AwsServiceRequestConfiguration
The configuration for an
AWS_SERVICE_REQUESTfunction. -
#concurrent_executor_configuration ⇒ Types::ConcurrentExecutorConfiguration
The configuration for a
CONCURRENT_EXECUTORfunction. -
#custom_output_configuration ⇒ Types::CustomOutputConfiguration
The configuration for a
CUSTOM_OUTPUTfunction. -
#description ⇒ String
A description of the function.
-
#function_id ⇒ String
The identifier of the function.
-
#function_type ⇒ String
The type of the function.
-
#http_request_configuration ⇒ Types::HttpRequestConfiguration
The configuration for an
HTTP_REQUESTfunction. -
#sequential_executor_configuration ⇒ Types::SequentialExecutorConfiguration
The configuration for a
SEQUENTIAL_EXECUTORfunction. -
#tags ⇒ Hash<String,String>
The tags assigned to the function.
-
#vast_request_configuration ⇒ Types::VastRequestConfiguration
The configuration for a
VAST_REQUESTfunction.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the function.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#aws_service_request_configuration ⇒ Types::AwsServiceRequestConfiguration
The configuration for an AWS_SERVICE_REQUEST function. Specifies
the target service, target Region, and request parameters.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#concurrent_executor_configuration ⇒ Types::ConcurrentExecutorConfiguration
The configuration for a CONCURRENT_EXECUTOR function.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#custom_output_configuration ⇒ Types::CustomOutputConfiguration
The configuration for a CUSTOM_OUTPUT function.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the function.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#function_id ⇒ String
The identifier of the function.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#function_type ⇒ String
The type of the function.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#http_request_configuration ⇒ Types::HttpRequestConfiguration
The configuration for an HTTP_REQUEST function.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#sequential_executor_configuration ⇒ Types::SequentialExecutorConfiguration
The configuration for a SEQUENTIAL_EXECUTOR function.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the function. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |
#vast_request_configuration ⇒ Types::VastRequestConfiguration
The configuration for a VAST_REQUEST function.
2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 2729 class GetFunctionResponse < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags, :arn) SENSITIVE = [] include Aws::Structure end |