Class: Aws::MediaTailor::Types::HlsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::HlsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
The configuration for HLS content.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dual_stack_manifest_endpoint_prefix ⇒ String
The dual-stack (IPv4 and IPv6) URL that MediaTailor generates to initiate a playback session for devices that support Apple HLS.
-
#manifest_endpoint_prefix ⇒ String
The URL that MediaTailor generates to initiate a playback session for devices that support Apple HLS.
Instance Attribute Details
#dual_stack_manifest_endpoint_prefix ⇒ String
The dual-stack (IPv4 and IPv6) URL that MediaTailor generates to initiate a playback session for devices that support Apple HLS. The session uses server-side reporting.
3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3103 class HlsConfiguration < Struct.new( :manifest_endpoint_prefix, :dual_stack_manifest_endpoint_prefix) SENSITIVE = [] include Aws::Structure end |
#manifest_endpoint_prefix ⇒ String
The URL that MediaTailor generates to initiate a playback session for devices that support Apple HLS. The session uses server-side reporting.
3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3103 class HlsConfiguration < Struct.new( :manifest_endpoint_prefix, :dual_stack_manifest_endpoint_prefix) SENSITIVE = [] include Aws::Structure end |