Class: Aws::MediaTailor::Types::HttpRequestConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::HttpRequestConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
The configuration for an HTTP_REQUEST function. Specifies the HTTP
method, URL, headers, body, timeout, and output expressions for the
request. For more information, see HTTP_REQUEST in the
MediaTailor User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#body ⇒ String
An expression that evaluates to the request body.
-
#headers ⇒ Hash<String,String>
A map of HTTP header names to expression values.
-
#method_type ⇒ String
The HTTP method for the request.
-
#output ⇒ Hash<String,String>
A map of output bindings.
-
#request_timeout_milliseconds ⇒ Integer
The maximum time, in milliseconds, that MediaTailor waits for a response from the external service.
-
#runtime ⇒ String
The expression language used to evaluate expressions in the function configuration.
-
#url ⇒ String
An expression that evaluates to the request URL.
Instance Attribute Details
#body ⇒ String
An expression that evaluates to the request body. Used with POST
requests. The maximum size after evaluation is 64 KB.
3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3272 class HttpRequestConfiguration < Struct.new( :runtime, :output, :method_type, :request_timeout_milliseconds, :url, :body, :headers) SENSITIVE = [] include Aws::Structure end |
#headers ⇒ Hash<String,String>
A map of HTTP header names to expression values. MediaTailor evaluates each header value expression at runtime and includes the result in the outbound HTTP request. Maximum 50 headers.
3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3272 class HttpRequestConfiguration < Struct.new( :runtime, :output, :method_type, :request_timeout_milliseconds, :url, :body, :headers) SENSITIVE = [] include Aws::Structure end |
#method_type ⇒ String
The HTTP method for the request. Valid values: GET and POST.
3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3272 class HttpRequestConfiguration < Struct.new( :runtime, :output, :method_type, :request_timeout_milliseconds, :url, :body, :headers) SENSITIVE = [] include Aws::Structure end |
#output ⇒ Hash<String,String>
A map of output bindings. Each key is a namespaced output path (such
as player_params.device_type or temp.identity), and each value
is an expression that MediaTailor evaluates at runtime. Output
expressions in an HTTP_REQUEST function can reference the
response object returned by the HTTP call. For more information
about expression syntax, see JSONata expression reference in
the MediaTailor User Guide.
3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3272 class HttpRequestConfiguration < Struct.new( :runtime, :output, :method_type, :request_timeout_milliseconds, :url, :body, :headers) SENSITIVE = [] include Aws::Structure end |
#request_timeout_milliseconds ⇒ Integer
The maximum time, in milliseconds, that MediaTailor waits for a
response from the external service. If the call exceeds this
timeout, MediaTailor sets the response status code to null and
proceeds with output expression evaluation. Valid values: 100 to
2000.
3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3272 class HttpRequestConfiguration < Struct.new( :runtime, :output, :method_type, :request_timeout_milliseconds, :url, :body, :headers) SENSITIVE = [] include Aws::Structure end |
#runtime ⇒ String
The expression language used to evaluate expressions in the function
configuration. Set this to JSONata.
3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3272 class HttpRequestConfiguration < Struct.new( :runtime, :output, :method_type, :request_timeout_milliseconds, :url, :body, :headers) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
An expression that evaluates to the request URL. Use {%...%}
delimiters for dynamic expressions. The maximum length after
evaluation is 2,048 characters.
3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 3272 class HttpRequestConfiguration < Struct.new( :runtime, :output, :method_type, :request_timeout_milliseconds, :url, :body, :headers) SENSITIVE = [] include Aws::Structure end |