Class: Aws::MediaTailor::Types::PreRollVastResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::PreRollVastResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
The settings that control how MediaTailor processes VAST responses from the ad decision server for live pre-roll ad breaks.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_sequencing_mode ⇒ String
The ad sequencing mode for live pre-roll ads.
Instance Attribute Details
#ad_sequencing_mode ⇒ String
The ad sequencing mode for live pre-roll ads. FOLLOW_AD_SEQUENCE
inserts sequenced ads in increasing order and uses standalone ads
only as replacements when a sequenced ad fails. IGNORE_AD_SEQUENCE
inserts ads in the order they appear in the VAST response,
regardless of sequence attributes. The default behavior is
IGNORE_AD_SEQUENCE.
4306 4307 4308 4309 4310 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4306 class PreRollVastResponse < Struct.new( :ad_sequencing_mode) SENSITIVE = [] include Aws::Structure end |