Class: Aws::MediaTailor::Types::PrefetchSchedule
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::PrefetchSchedule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
A prefetch schedule allows you to tell MediaTailor to fetch and prepare certain ads before an ad break happens. For more information about ad prefetching, see Using ad prefetching in the MediaTailor User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the prefetch schedule.
-
#consumption ⇒ Types::PrefetchConsumption
Consumption settings determine how, and when, MediaTailor places the prefetched ads into ad breaks for single prefetch schedules.
-
#name ⇒ String
The name of the prefetch schedule.
-
#playback_configuration_name ⇒ String
The name of the playback configuration to create the prefetch schedule for.
-
#recurring_prefetch_configuration ⇒ Types::RecurringPrefetchConfiguration
The settings that determine how and when MediaTailor prefetches ads and inserts them into ad breaks.
-
#retrieval ⇒ Types::PrefetchRetrieval
A complex type that contains settings for prefetch retrieval from the ad decision server (ADS).
-
#schedule_type ⇒ String
The frequency that MediaTailor creates prefetch schedules.
-
#stream_id ⇒ String
An optional stream identifier that you can specify in order to prefetch for multiple streams that use the same playback configuration.
-
#tags ⇒ Hash<String,String>
The tags assigned to the prefetch schedule.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the prefetch schedule.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484 class PrefetchSchedule < Struct.new( :arn, :consumption, :name, :playback_configuration_name, :retrieval, :schedule_type, :recurring_prefetch_configuration, :stream_id, :tags) SENSITIVE = [] include Aws::Structure end |
#consumption ⇒ Types::PrefetchConsumption
Consumption settings determine how, and when, MediaTailor places the prefetched ads into ad breaks for single prefetch schedules. Ad consumption occurs within a span of time that you define, called a consumption window. You can designate which ad breaks that MediaTailor fills with prefetch ads by setting avail matching criteria.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484 class PrefetchSchedule < Struct.new( :arn, :consumption, :name, :playback_configuration_name, :retrieval, :schedule_type, :recurring_prefetch_configuration, :stream_id, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the prefetch schedule. The name must be unique among all prefetch schedules that are associated with the specified playback configuration.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484 class PrefetchSchedule < Struct.new( :arn, :consumption, :name, :playback_configuration_name, :retrieval, :schedule_type, :recurring_prefetch_configuration, :stream_id, :tags) SENSITIVE = [] include Aws::Structure end |
#playback_configuration_name ⇒ String
The name of the playback configuration to create the prefetch schedule for.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484 class PrefetchSchedule < Struct.new( :arn, :consumption, :name, :playback_configuration_name, :retrieval, :schedule_type, :recurring_prefetch_configuration, :stream_id, :tags) SENSITIVE = [] include Aws::Structure end |
#recurring_prefetch_configuration ⇒ Types::RecurringPrefetchConfiguration
The settings that determine how and when MediaTailor prefetches ads and inserts them into ad breaks.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484 class PrefetchSchedule < Struct.new( :arn, :consumption, :name, :playback_configuration_name, :retrieval, :schedule_type, :recurring_prefetch_configuration, :stream_id, :tags) SENSITIVE = [] include Aws::Structure end |
#retrieval ⇒ Types::PrefetchRetrieval
A complex type that contains settings for prefetch retrieval from the ad decision server (ADS).
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484 class PrefetchSchedule < Struct.new( :arn, :consumption, :name, :playback_configuration_name, :retrieval, :schedule_type, :recurring_prefetch_configuration, :stream_id, :tags) SENSITIVE = [] include Aws::Structure end |
#schedule_type ⇒ String
The frequency that MediaTailor creates prefetch schedules. SINGLE
indicates that this schedule applies to one ad break. RECURRING
indicates that MediaTailor automatically creates a schedule for each
ad avail in a live event.
For more information about the prefetch types and when you might use each, see Prefetching ads in Elemental MediaTailor.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484 class PrefetchSchedule < Struct.new( :arn, :consumption, :name, :playback_configuration_name, :retrieval, :schedule_type, :recurring_prefetch_configuration, :stream_id, :tags) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
An optional stream identifier that you can specify in order to prefetch for multiple streams that use the same playback configuration.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484 class PrefetchSchedule < Struct.new( :arn, :consumption, :name, :playback_configuration_name, :retrieval, :schedule_type, :recurring_prefetch_configuration, :stream_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the prefetch schedule. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4484 class PrefetchSchedule < Struct.new( :arn, :consumption, :name, :playback_configuration_name, :retrieval, :schedule_type, :recurring_prefetch_configuration, :stream_id, :tags) SENSITIVE = [] include Aws::Structure end |