Class: Aws::MediaTailor::Types::PutFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::PutFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
-- Define Mixin --
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_service_request_configuration ⇒ Types::AwsServiceRequestConfiguration
The configuration for an
AWS_SERVICE_REQUESTfunction. -
#concurrent_executor_configuration ⇒ Types::ConcurrentExecutorConfiguration
The configuration for a
CONCURRENT_EXECUTORfunction. -
#custom_output_configuration ⇒ Types::CustomOutputConfiguration
The configuration for a
CUSTOM_OUTPUTfunction. -
#description ⇒ String
A description of the function.
-
#function_id ⇒ String
The identifier of the function.
-
#function_type ⇒ String
The type of the function, which determines what the function can do at runtime.
-
#http_request_configuration ⇒ Types::HttpRequestConfiguration
The configuration for an
HTTP_REQUESTfunction. -
#sequential_executor_configuration ⇒ Types::SequentialExecutorConfiguration
The configuration for a
SEQUENTIAL_EXECUTORfunction. -
#tags ⇒ Hash<String,String>
The tags to assign to the function.
-
#vast_request_configuration ⇒ Types::VastRequestConfiguration
The configuration for a
VAST_REQUESTfunction.
Instance Attribute Details
#aws_service_request_configuration ⇒ Types::AwsServiceRequestConfiguration
The configuration for an AWS_SERVICE_REQUEST function. You must
specify this parameter when FunctionType is AWS_SERVICE_REQUEST.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#concurrent_executor_configuration ⇒ Types::ConcurrentExecutorConfiguration
The configuration for a CONCURRENT_EXECUTOR function. Specifies
the list of child functions to run in parallel, the maximum
concurrency, an optional output block, and a timeout. Required when
FunctionType is CONCURRENT_EXECUTOR.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#custom_output_configuration ⇒ Types::CustomOutputConfiguration
The configuration for a CUSTOM_OUTPUT function. Specifies the
runtime and output expressions. Required when FunctionType is
CUSTOM_OUTPUT.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the function.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#function_id ⇒ String
The identifier of the function. The identifier must be unique within your account.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#function_type ⇒ String
The type of the function, which determines what the function can do at runtime. Valid values:
-
CUSTOM_OUTPUT– Evaluates expressions and produces output bindings with no external calls. -
HTTP_REQUEST– Makes an HTTP call to an external service and evaluates output expressions that can reference the response. -
AWS_SERVICE_REQUEST– Makes an authenticated request to a supported AWS service API and evaluates output expressions that can reference the response. -
VAST_REQUEST– Calls a VAST endpoint, parses the response as VAST, and makes the parsed ads available to output expressions. -
SEQUENTIAL_EXECUTOR– Runs a sequence of child functions in order, passing data between steps through temporary data. -
CONCURRENT_EXECUTOR– Runs a set of child functions in parallel, up to a maximum concurrency, and combines their output when all functions complete.
For more information, see Function types and composition in the MediaTailor User Guide.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#http_request_configuration ⇒ Types::HttpRequestConfiguration
The configuration for an HTTP_REQUEST function. Specifies the HTTP
method, URL, headers, body, timeout, and output expressions.
Required when FunctionType is HTTP_REQUEST.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#sequential_executor_configuration ⇒ Types::SequentialExecutorConfiguration
The configuration for a SEQUENTIAL_EXECUTOR function. Specifies
the ordered list of child functions to execute, an optional output
block, and a timeout. Required when FunctionType is
SEQUENTIAL_EXECUTOR.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the function. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#vast_request_configuration ⇒ Types::VastRequestConfiguration
The configuration for a VAST_REQUEST function. Specifies the HTTP
method, URL, headers, body, timeout, and output expressions.
Required when FunctionType is VAST_REQUEST.
4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 4612 class PutFunctionRequest < Struct.new( :function_id, :function_type, :description, :http_request_configuration, :aws_service_request_configuration, :custom_output_configuration, :concurrent_executor_configuration, :sequential_executor_configuration, :vast_request_configuration, :tags) SENSITIVE = [] include Aws::Structure end |