Class: Aws::MediaTailor::Types::SourceLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::SourceLocation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
A source location is a container for sources. For more information about source locations, see Working with source locations in the MediaTailor User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_configuration ⇒ Types::AccessConfiguration
The access configuration for the source location.
-
#arn ⇒ String
The ARN of the SourceLocation.
-
#creation_time ⇒ Time
The timestamp that indicates when the source location was created.
-
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The default segment delivery configuration.
-
#http_configuration ⇒ Types::HttpConfiguration
The HTTP configuration for the source location.
-
#last_modified_time ⇒ Time
The timestamp that indicates when the source location was last modified.
-
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
The segment delivery configurations for the source location.
-
#source_location_name ⇒ String
The name of the source location.
-
#tags ⇒ Hash<String,String>
The tags assigned to the source location.
Instance Attribute Details
#access_configuration ⇒ Types::AccessConfiguration
The access configuration for the source location.
5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686 class SourceLocation < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the SourceLocation.
5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686 class SourceLocation < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp that indicates when the source location was created.
5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686 class SourceLocation < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The default segment delivery configuration.
5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686 class SourceLocation < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#http_configuration ⇒ Types::HttpConfiguration
The HTTP configuration for the source location.
5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686 class SourceLocation < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp that indicates when the source location was last modified.
5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686 class SourceLocation < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
The segment delivery configurations for the source location.
5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686 class SourceLocation < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location.
5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686 class SourceLocation < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the source location. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5686 class SourceLocation < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |