Class: Aws::MediaTailor::Types::TrafficShapingRetrievalWindow
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::TrafficShapingRetrievalWindow
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
The configuration that tells Elemental MediaTailor how many seconds to spread out requests to the ad decision server (ADS). Instead of sending ADS requests for all sessions at the same time, MediaTailor spreads the requests across the amount of time specified in the retrieval window.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#retrieval_window_duration_seconds ⇒ Integer
The amount of time, in seconds, that MediaTailor spreads prefetch requests to the ADS.
Instance Attribute Details
#retrieval_window_duration_seconds ⇒ Integer
The amount of time, in seconds, that MediaTailor spreads prefetch requests to the ADS.
5847 5848 5849 5850 5851 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 5847 class TrafficShapingRetrievalWindow < Struct.new( :retrieval_window_duration_seconds) SENSITIVE = [] include Aws::Structure end |