Class: Aws::MediaTailor::Types::UpdateChannelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::UpdateChannelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the channel.
-
#audiences ⇒ Array<String>
The list of audiences defined in channel.
-
#channel_name ⇒ String
The name of the channel.
-
#channel_state ⇒ String
Returns the state whether the channel is running or not.
-
#creation_time ⇒ Time
The timestamp of when the channel was created.
-
#filler_slate ⇒ Types::SlateSource
The slate used to fill gaps between programs in the schedule.
-
#last_modified_time ⇒ Time
The timestamp that indicates when the channel was last modified.
-
#outputs ⇒ Array<Types::ResponseOutputItem>
The channel's output properties.
-
#playback_mode ⇒ String
The type of playback mode for this channel.
-
#tags ⇒ Hash<String,String>
The tags to assign to the channel.
-
#tier ⇒ String
The tier associated with this Channel.
-
#time_shift_configuration ⇒ Types::TimeShiftConfiguration
The time-shifted viewing configuration for the channel.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the channel.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#audiences ⇒ Array<String>
The list of audiences defined in channel.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#channel_state ⇒ String
Returns the state whether the channel is running or not.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp of when the channel was created.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#filler_slate ⇒ Types::SlateSource
The slate used to fill gaps between programs in the schedule. You
must configure filler slate if your channel uses the LINEAR
PlaybackMode. MediaTailor doesn't support filler slate for
channels using the LOOP PlaybackMode.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp that indicates when the channel was last modified.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::ResponseOutputItem>
The channel's output properties.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#playback_mode ⇒ String
The type of playback mode for this channel.
LINEAR - Programs play back-to-back only once.
LOOP - Programs play back-to-back in an endless loop. When the
last program in the schedule plays, playback loops back to the first
program in the schedule.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the channel. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
The tier associated with this Channel.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |
#time_shift_configuration ⇒ Types::TimeShiftConfiguration
The time-shifted viewing configuration for the channel.
6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6053 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_state, :creation_time, :filler_slate, :last_modified_time, :outputs, :playback_mode, :tags, :tier, :time_shift_configuration, :audiences) SENSITIVE = [] include Aws::Structure end |