Class: Aws::MediaTailor::Types::UpdateSourceLocationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::UpdateSourceLocationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_configuration ⇒ Types::AccessConfiguration
Access configuration parameters.
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the source location.
-
#creation_time ⇒ Time
The timestamp that indicates when the source location was created.
-
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The optional configuration for the host server that serves segments.
-
#http_configuration ⇒ Types::HttpConfiguration
The HTTP configuration for the source location.
-
#last_modified_time ⇒ Time
The timestamp that indicates when the source location was last modified.
-
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
The segment delivery configurations for the source location.
-
#source_location_name ⇒ String
The name of the source location.
-
#tags ⇒ Hash<String,String>
The tags to assign to the source location.
Instance Attribute Details
#access_configuration ⇒ Types::AccessConfiguration
Access configuration parameters. Configures the type of authentication used to access content from your source location.
6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6380 class UpdateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the source location.
6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6380 class UpdateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The timestamp that indicates when the source location was created.
6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6380 class UpdateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#default_segment_delivery_configuration ⇒ Types::DefaultSegmentDeliveryConfiguration
The optional configuration for the host server that serves segments.
6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6380 class UpdateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#http_configuration ⇒ Types::HttpConfiguration
The HTTP configuration for the source location.
6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6380 class UpdateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp that indicates when the source location was last modified.
6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6380 class UpdateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#segment_delivery_configurations ⇒ Array<Types::SegmentDeliveryConfiguration>
The segment delivery configurations for the source location. For information about MediaTailor configurations, see Working with configurations in AWS Elemental MediaTailor.
6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6380 class UpdateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#source_location_name ⇒ String
The name of the source location.
6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6380 class UpdateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the source location. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6380 class UpdateSourceLocationResponse < Struct.new( :access_configuration, :arn, :creation_time, :default_segment_delivery_configuration, :http_configuration, :last_modified_time, :segment_delivery_configurations, :source_location_name, :tags) SENSITIVE = [] include Aws::Structure end |