Class: Aws::MediaTailor::Types::VastResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::VastResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
The settings that control how MediaTailor processes VAST responses from the ad decision server.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_sequencing_mode ⇒ String
The ad sequencing mode that controls how MediaTailor handles sequenced and standalone ads in VAST responses.
Instance Attribute Details
#ad_sequencing_mode ⇒ String
The ad sequencing mode that controls how MediaTailor handles
sequenced and standalone ads in VAST responses. FOLLOW_AD_SEQUENCE
inserts sequenced ads in increasing order for both live and VOD
workflows, using standalone ads only as replacements when a
sequenced ad fails. FOLLOW_AD_SEQUENCE_ONLY_LIVE enables ad
sequencing for live workflows only. FOLLOW_AD_SEQUENCE_ONLY_VOD
enables ad sequencing for VOD workflows only. IGNORE_AD_SEQUENCE
inserts ads in the order they appear in the VAST response,
regardless of sequence attributes. The default behavior is
IGNORE_AD_SEQUENCE.
6567 6568 6569 6570 6571 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6567 class VastResponse < Struct.new( :ad_sequencing_mode) SENSITIVE = [] include Aws::Structure end |