Class: Aws::MediaTailor::Types::YieldOptimizationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaTailor::Types::YieldOptimizationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediatailor/types.rb
Overview
Configuration for Yield Optimization, which fills unsold ad inventory in ad breaks with programmatic ads from Amazon Publisher Services (APS).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#minimum_unfilled_duration ⇒ Integer
The minimum unfilled duration, in seconds, that must remain in an ad break before MediaTailor requests additional ads from Amazon Publisher Services (APS).
-
#open_rtb_template ⇒ String
The OpenRTB bid request template, in JSON, that MediaTailor sends to Amazon Publisher Services (APS).
-
#publisher_id ⇒ String
Publisher ID for an existing Amazon Publisher Services configuration.
-
#region ⇒ String
The Amazon Publisher Services (APS) region that MediaTailor sends bid requests to.
Instance Attribute Details
#minimum_unfilled_duration ⇒ Integer
The minimum unfilled duration, in seconds, that must remain in an ad break before MediaTailor requests additional ads from Amazon Publisher Services (APS). For example, if set to 6 seconds, yield optimization triggers only when at least 6 seconds of unfilled time remains after the primary ad server response.
6667 6668 6669 6670 6671 6672 6673 6674 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6667 class YieldOptimizationConfiguration < Struct.new( :minimum_unfilled_duration, :publisher_id, :region, :open_rtb_template) SENSITIVE = [] include Aws::Structure end |
#open_rtb_template ⇒ String
The OpenRTB bid request template, in JSON, that MediaTailor sends to
Amazon Publisher Services (APS). The template must include an imp
array with one impression specifying bidfloor, an app object
specifying bundle and storeurl, and a device object specifying
ua and ip. Use double curly braces (for example,
{{player_params.user_agent}}) to insert session variables and
player parameters.
6667 6668 6669 6670 6671 6672 6673 6674 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6667 class YieldOptimizationConfiguration < Struct.new( :minimum_unfilled_duration, :publisher_id, :region, :open_rtb_template) SENSITIVE = [] include Aws::Structure end |
#publisher_id ⇒ String
Publisher ID for an existing Amazon Publisher Services configuration. This ID must be obtained by registering with APS prior to using the Yield Optimization feature. The Publisher ID identifies your account in the APS system and is required for all bid requests.
6667 6668 6669 6670 6671 6672 6673 6674 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6667 class YieldOptimizationConfiguration < Struct.new( :minimum_unfilled_duration, :publisher_id, :region, :open_rtb_template) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Publisher Services (APS) region that MediaTailor sends bid requests to. Choose the region closest to your primary audience, because the selection affects both latency and the ad inventory available to you. This setting applies to the entire playback configuration, not to individual viewers. If you serve traffic across multiple regions, create a separate playback configuration for each APS region.
6667 6668 6669 6670 6671 6672 6673 6674 |
# File 'lib/aws-sdk-mediatailor/types.rb', line 6667 class YieldOptimizationConfiguration < Struct.new( :minimum_unfilled_duration, :publisher_id, :region, :open_rtb_template) SENSITIVE = [] include Aws::Structure end |